@@ -1,16 +1,11 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division
-
 import datetime
-import warnings
 
 import astropy.units as u
 from astropy.time import Time
-from astropy.coordinates import TimeAttribute, CoordinateAttribute, get_body_barycentric, ICRS
+from astropy.coordinates import TimeAttribute, CoordinateAttribute
 
-from sunpy.extern import six
 from sunpy.time import parse_time
-from sunpy.util.exceptions import SunpyUserWarning
 
 __all__ = ['TimeFrameAttributeSunPy', 'ObserverCoordinateAttribute']
 
@@ -66,17 +61,17 @@ class TimeFrameAttributeSunPy(TimeAttribute):
             out = value
             converted = False
 
-        elif isinstance(value, six.string_types):
+        elif isinstance(value, str):
             try:
                 out = Time(parse_time(value))
             except Exception as err:
-                raise ValueError('Invalid time input {0}={1!r}\n{2}'.format(self.name, value, err))
+                raise ValueError(f'Invalid time input {self.name}={value!r}\n{err}')
             converted = True
         else:
             try:
                 out = Time(value)
             except Exception as err:
-                raise ValueError('Invalid time input {0}={1!r}\n{2}'.format(self.name, value, err))
+                raise ValueError(f'Invalid time input {self.name}={value!r}\n{err}')
             converted = True
 
         return out, converted
@@ -105,10 +100,10 @@ class ObserverCoordinateAttribute(CoordinateAttribute):
 
     def convert_input(self, value):
         # Keep string here.
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             return value, False
         else:
-            return super(ObserverCoordinateAttribute, self).convert_input(value)
+            return super().convert_input(value)
 
     def _convert_string_to_coord(self, out, obstime):
         """
@@ -140,11 +135,12 @@ class ObserverCoordinateAttribute(CoordinateAttribute):
 
             # If the observer is a string and we have obstime then calculate
             # the position of the observer.
-            if isinstance(observer, six.string_types):
+            if isinstance(observer, str):
                 if obstime is not None:
-                    observer = self._convert_string_to_coord(observer.lower(), obstime)
-                    setattr(instance, '_' + self.name, observer)
+                    new_observer = self._convert_string_to_coord(observer.lower(), obstime)
+                    new_observer.object_name = observer
+                    setattr(instance, '_' + self.name, new_observer)
                 else:
                     return observer
 
-        return super(ObserverCoordinateAttribute, self).__get__(instance, frame_cls=frame_cls)
+        return super().__get__(instance, frame_cls=frame_cls)
