@@ -4,7 +4,7 @@ from astropy.coordinates import SkyOffsetFrame, SphericalRepresentation, UnitSph
 __all__ = ['NorthOffsetFrame']
 
 
-class NorthOffsetFrame(object):
+class NorthOffsetFrame:
     """
     A frame which is relative to some position and another frame. Based on
     `astropy.coordinates.SkyOffsetFrame`
@@ -97,13 +97,13 @@ class NorthOffsetFrame(object):
             rotation = 180*u.deg
 
         if isinstance(origin_frame.data, UnitSphericalRepresentation):
-            new_rep = origin_frame.representation(lon=lon,
-                                                  lat=lat)
+            new_rep = origin_frame.representation_type(lon=lon,
+                                                       lat=lat)
 
         else:
-            new_rep = origin_frame.representation(lon=lon,
-                                                  lat=lat,
-                                                  distance=rep.distance)
+            new_rep = origin_frame.representation_type(lon=lon,
+                                                       lat=lat,
+                                                       distance=rep.distance)
 
         new_origin = origin_frame.realize_frame(new_rep)
         kwargs['origin'] = new_origin
