@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 
-from datetime import datetime
 import numpy as np
 
 import pytest
 
+from sunpy.time import parse_time
+
 import astropy.units as u
 
 from astropy.tests.helper import assert_quantity_allclose
@@ -39,7 +40,7 @@ These are common 2D params, kwargs are frame specific
 two_D_parameters = [
     ([0 * u.deg, 0 * u.arcsec], None),
     ([0 * u.deg, 0 * u.arcsec], {'obstime': '2011/01/01T00:00:00'}),
-    ([0 * u.deg, 0 * u.arcsec], {'representation': 'unitspherical'}),
+    ([0 * u.deg, 0 * u.arcsec], {'representation_type': 'unitspherical'}),
     ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], None),
     ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], None), (
         [UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)],
@@ -51,7 +52,7 @@ These are common 3D params, kwargs are frame specific
 three_D_parameters = [
     ([0 * u.deg, 0 * u.arcsec, 1 * u.Mm], None),
     ([0 * u.deg, 0 * u.arcsec, 1 * u.Mm], {'obstime': '2011/01/01T00:00:00'}),
-    ([0 * u.deg, 0 * u.arcsec, 1 * u.Mm], {'representation': 'spherical'}),
+    ([0 * u.deg, 0 * u.arcsec, 1 * u.Mm], {'representation_type': 'spherical'}),
     ([SphericalRepresentation(0 * u.deg, 0 * u.arcsec, 1 * u.Mm)],
      None),
     ([SphericalRepresentation(0 * u.deg, 0 * u.arcsec, 1 * u.Mm)], None), (
@@ -72,7 +73,7 @@ def test_create_hpc_2d(args, kwargs):
 
     # Check we have the right class!
     assert isinstance(hpc1, Helioprojective)
-    rep_kwarg = kwargs.get('representation', None) if kwargs else None
+    rep_kwarg = kwargs.get('representation_type', None) if kwargs else None
 
     if rep_kwarg and rep_kwarg == 'unitspherical':
         # Check that we have a unitspherical representation
@@ -101,7 +102,7 @@ def test_create_3d(args, kwargs):
 
     # Check we have the right class!
     assert isinstance(hpc1, Helioprojective)
-    rep_kwarg = kwargs.get('representation', None) if kwargs else None
+    rep_kwarg = kwargs.get('representation_type', None) if kwargs else None
 
     if rep_kwarg and rep_kwarg == 'spherical':
         # Check that we have a unitspherical representation
@@ -152,6 +153,16 @@ def test_hpc_distance():
     assert_quantity_allclose(hpc2.distance, DSUN_METERS - RSUN_METERS)
 
 
+def test_hpc_distance_cartesian():
+    # Test detection of distance in other representations
+    hpc1 = Helioprojective(CartesianRepresentation(0 * u.km, 0 * u.km, 1 * u.Mm))
+
+    assert isinstance(hpc1, Helioprojective)
+    assert isinstance(hpc1._data, CartesianRepresentation)
+
+    assert hpc1.calculate_distance() is hpc1
+
+
 def test_hpc_distance_off_limb():
     hpc1 = Helioprojective(1500 * u.arcsec, 0 * u.arcsec,
                            observer=HeliographicStonyhurst(0*u.deg, 0*u.deg, 1*u.AU))
@@ -202,6 +213,15 @@ def test_wrapping_off():
     assert_quantity_allclose(hpc1.Tx.wrap_angle, 360*u.deg)
 
 
+def test_hpc_default_observer():
+    # Observer is considered default if it hasn't been specified *and* if obstime isn't specified
+    hpc = Helioprojective(0*u.arcsec, 0*u.arcsec)
+    assert hpc.is_frame_attr_default('observer')
+
+    hpc = Helioprojective(0*u.arcsec, 0*u.arcsec, obstime='2019-06-01')
+    assert not hpc.is_frame_attr_default('observer')
+
+
 # ==============================================================================
 # ## Heliographic Tests
 # ==============================================================================
@@ -209,12 +229,12 @@ def test_wrapping_off():
 def test_HEE_creation():
     # Smoke test to make sure HEE constructors work fine
     _ = HeliographicStonyhurst(lon=0*u.deg, lat=90*u.deg,
-                               obstime=datetime(2018, 12, 21))
+                               obstime=parse_time('2018-12-21'))
     _ = HeliographicStonyhurst(lon=0*u.deg, lat=90*u.deg, radius=1*u.km,
-                               obstime=datetime(2018, 12, 21))
+                               obstime=parse_time('2018-12-21'))
     _ = HeliographicStonyhurst(x=1*u.km, y=1*u.km, z=1*u.km,
-                               obstime=datetime(2018, 12, 21),
-                               representation='cartesian')
+                               obstime=parse_time('2018-12-21'),
+                               representation_type='cartesian')
 
 @pytest.mark.parametrize('frame',
                          [HeliographicStonyhurst, HeliographicCarrington])
@@ -252,7 +272,7 @@ def test_create_hgs_force_2d(frame, args, kwargs):
     # Check we have the right class!
     assert isinstance(hgs1, frame)
 
-    rep_kwarg = kwargs.get('representation', None) if kwargs else None
+    rep_kwarg = kwargs.get('representation_type', None) if kwargs else None
 
     if rep_kwarg == 'unitspherical':
         assert isinstance(hgs1._data, UnitSphericalRepresentation)
@@ -280,7 +300,7 @@ def test_create_hgs_3d(frame, args, kwargs):
     # Check we have the right class!
     assert isinstance(hgs1, frame)
 
-    rep_kwarg = kwargs.get('representation', None) if kwargs else None
+    rep_kwarg = kwargs.get('representation_type', None) if kwargs else None
 
     if rep_kwarg == 'spherical':
         assert isinstance(hgs1._data, SphericalRepresentation)
@@ -357,6 +377,16 @@ def test_create_hcc_3d(args, kwargs):
     assert hcc.y.unit is u.km
     assert hcc.z.unit is u.km
 
+
+def test_hcc_default_observer():
+    # Observer is considered default if it hasn't been specified *and* if obstime isn't specified
+    hcc = Heliocentric(0*u.AU, 0*u.AU, 0*u.AU)
+    assert hcc.is_frame_attr_default('observer')
+
+    hcc = Heliocentric(0*u.AU, 0*u.AU, 0*u.AU, obstime='2019-06-01')
+    assert not hcc.is_frame_attr_default('observer')
+
+
 # ==============================================================================
 # SkyCoord Tests
 # ==============================================================================
@@ -372,19 +402,14 @@ two_D_parameters = [
 
 @pytest.mark.parametrize("args, kwargs",
                          two_D_parameters + [([0 * u.deg, 0 * u.arcsec],
-                                              {'representation': 'unitspherical'})])
+                                              {'representation_type': 'unitspherical'})])
 def test_skycoord_hpc(args, kwargs):
     """
     Test that when instantiating a HPC frame with SkyCoord calculate distance
     still works.
     """
 
-    # Python 3: These should just be keywords in the `SkyCoord` constructor
-    kwargs.update({
-        "frame": "helioprojective",
-        "obstime": "2011-01-01T00:00:00"
-        })
-    sc = SkyCoord(*args, **kwargs)
+    sc = SkyCoord(*args, **kwargs, frame="helioprojective", obstime="2011-01-01T00:00:00")
     # Test the transform to HGS because it will force a `calculate_distance` call.
     hgs = sc.transform_to("heliographic_stonyhurst")
 
@@ -402,12 +427,6 @@ def test_skycoord_hgs(args, kwargs):
     """
 
     RSUN_METERS = sun.constants.get('radius').si
-
-    # Python 3: These should just be keywords in the `SkyCoord` constructor
-    kwargs.update({
-        "frame": "heliographic_stonyhurst",
-        "obstime": "2011-01-01T00:00:00"
-        })
-    sc = SkyCoord(*args, **kwargs)
+    sc = SkyCoord(*args, **kwargs, frame="heliographic_stonyhurst", obstime="2011-01-01T00:00:00")
 
     assert_quantity_allclose(sc.radius, RSUN_METERS)
