@@ -2,8 +2,6 @@
 # Calculates the co-ordinates along great arcs between two specified points
 # which are assumed to be on disk.
 #
-from __future__ import absolute_import, division, print_function
-
 import numpy as np
 
 import astropy.units as u
@@ -14,7 +12,7 @@ from sunpy.coordinates import frames
 __all__ = ['GreatArc']
 
 
-class GreatArc(object):
+class GreatArc:
     """
     Calculate the properties of a great arc at user-specified points between a
     start and end point on a sphere.
@@ -30,7 +28,7 @@ class GreatArc(object):
     center : `~astropy.coordinates.SkyCoord`
         Center of the sphere.
 
-    points : `None`, `int`, `~numpy.ndarray`
+    points : `None`, `int`, `numpy.ndarray`
         Number of points along the great arc.  If None, the arc is calculated
         at 100 equally spaced points from start to end.  If int, the arc is
         calculated at "points" equally spaced points from start to end.  If a
@@ -101,11 +99,14 @@ class GreatArc(object):
         self.default_points = self._points_handler(points)
 
         # Units of the start point
-        self.distance_unit = self.start.transform_to(frames.Heliocentric).cartesian.xyz.unit
+        self.distance_unit = u.km
 
         # Co-ordinate frame
         self.start_frame = self.start.frame
 
+        # Observation time
+        self.obstime = self.start.obstime
+
         # Observer
         self.observer = self.start.observer
 
@@ -169,7 +170,7 @@ class GreatArc(object):
 
         Parameters
         ----------
-        points : `None`, `int`, `~numpy.ndarray`
+        points : `None`, `int`, `numpy.ndarray`
             If None, use the default locations of parameterized points along the
             arc.  If int, the arc is calculated at "points" equally spaced
             points from start to end.  If a numpy.ndarray is passed, it must be
@@ -195,7 +196,7 @@ class GreatArc(object):
 
         Parameters
         ----------
-        points : `None`, `int`, `~numpy.ndarray`
+        points : `None`, `int`, `numpy.ndarray`
             If None, use the default locations of parameterized points along the
             arc.  If int, the arc is calculated at "points" equally spaced
             points from start to end.  If a numpy.ndarray is passed, it must be
@@ -222,7 +223,7 @@ class GreatArc(object):
 
         Parameters
         ----------
-        points : `None`, `int`, `~numpy.ndarray`
+        points : `None`, `int`, `numpy.ndarray`
             If None, use the default locations of parameterized points along the
             arc.  If int, the arc is calculated at "points" equally spaced
             points from start to end.  If a numpy.ndarray is passed, it must be
@@ -251,4 +252,6 @@ class GreatArc(object):
         return SkyCoord(great_arc_points_cartesian[:, 0],
                         great_arc_points_cartesian[:, 1],
                         great_arc_points_cartesian[:, 2],
-                        frame=frames.Heliocentric, observer=self.observer).transform_to(self.start_frame)
+                        frame=frames.Heliocentric,
+                        obstime=self.obstime,
+                        observer=self.observer).transform_to(self.start_frame)
