@@ -3,18 +3,14 @@
 # This module was developed with funding provided by
 # the Google Summer of Code (2013).
 
-from __future__ import absolute_import
-
 from abc import ABCMeta, abstractmethod, abstractproperty
-from collections import MutableMapping, OrderedDict, Counter
-
-from sunpy.extern import six
+from collections import OrderedDict, Counter
+from collections.abc import MutableMapping
 
 __all__ = ['BaseCache', 'LRUCache', 'LFUCache']
 
 
-@six.add_metaclass(ABCMeta)
-class BaseCache(object):
+class BaseCache(metaclass=ABCMeta):
     """
     BaseCache is a class that saves and operates on an OrderedDict. It has a
     certain capacity, stored in the attribute `maxsize`. Whether this
@@ -99,12 +95,10 @@ class BaseCache(object):
         return len(self._dict)
 
     def __iter__(self):
-        for key in self._dict.__iter__():
-            yield key
+        yield from self._dict.__iter__()
 
     def __reversed__(self):  # pragma: no cover
-        for key in self._dict.__reversed__():
-            yield key
+        yield from self._dict.__reversed__()
 
     def clear(self):  # pragma: no cover
         return self._dict.clear()
@@ -122,12 +116,10 @@ class BaseCache(object):
         return iter(self._dict.keys())
 
     def itervalues(self):  # pragma: no cover
-        for value in self._dict.values():
-            yield value
+        yield from self._dict.values()
 
     def iteritems(self):  # pragma: no cover
-        for key, value in six.iteritems(self._dict):
-            yield key, value
+        yield from self._dict.items()
 
     def update(self, *args, **kwds):  # pragma: no cover
         self._dict.update(*args, **kwds)
@@ -167,7 +159,7 @@ class BaseCache(object):
         return OrderedDict.fromkeys(iterable, value)
 
     def __repr__(self):  # pragma: no cover
-        return '{0}({1!r})'.format(self.__class__.__name__, dict(self._dict))
+        return '{}({!r})'.format(self.__class__.__name__, dict(self._dict))
 
 
 class LRUCache(BaseCache):
@@ -180,7 +172,7 @@ class LRUCache(BaseCache):
         tuple.
 
         """
-        return six.next(self.iteritems())
+        return next(self.iteritems())
 
     def remove(self):
         """Remove the least recently used item."""
@@ -233,7 +225,7 @@ class LFUCache(BaseCache):
         """
         min_ = float('inf')
         lfu_key = None
-        for k, v in six.iteritems(self.usage_counter):
+        for k, v in self.usage_counter.items():
             if v < min_:
                 min_ = v
                 lfu_key = k
