@@ -1,20 +1,9 @@
-# Author: Simon Liedtke <liedtke.simon@googlemail.com>
-#
-# This module was developed with funding provided by
-# the Google Summer of Code (2013).
-
-from __future__ import absolute_import
-
-from abc import ABCMeta, abstractmethod
 import os
+from abc import ABC, abstractmethod
 
 from sqlalchemy.orm import make_transient
 from sqlalchemy.exc import InvalidRequestError
 
-from sunpy.extern import six
-
-from sunpy.extern.six.moves import range
-
 __all__ = [
     'EmptyCommandStackError', 'NoSuchEntryError', 'NonRemovableTagError',
     'DatabaseOperation', 'AddEntry', 'RemoveEntry', 'EditEntry',
@@ -38,7 +27,7 @@ class NoSuchEntryError(Exception):
 
     def __str__(self):  # pragma: no cover
         return (
-            'the database entry {0!r} cannot be removed because it '
+            'the database entry {!r} cannot be removed because it '
             'is not stored in the database'.format(self.database_entry))
 
 
@@ -56,8 +45,7 @@ class NonRemovableTagError(Exception):
         return errmsg.format(self.database_entry, self.tag)
 
 
-@six.add_metaclass(ABCMeta)
-class DatabaseOperation(object):
+class DatabaseOperation(ABC):
     """This is the abstract main class for all database operations. To
     implement a new operation, inherit from this class and override the methods
     __call__ and undo. Both these methods get no parameters (except for self of
@@ -138,7 +126,7 @@ class AddEntry(DatabaseOperation):
             make_transient(self.database_entry)
 
     def __repr__(self):
-        return '<{0}(session {1!r}, entry id {2})>'.format(
+        return '<{}(session {!r}, entry id {})>'.format(
             self.__class__.__name__, self.session, self.database_entry.id)
 
 
@@ -166,7 +154,7 @@ class RemoveEntry(DatabaseOperation):
         self.session.add(self.entry)
 
     def __repr__(self):
-        return '<{0}(session {1!r}, entry {2!r})>'.format(
+        return '<{}(session {!r}, entry {!r})>'.format(
             self.__class__.__name__, self.session, self.entry)
 
 
@@ -186,18 +174,18 @@ class EditEntry(DatabaseOperation):
         self.prev_values = {}
 
     def __call__(self):
-        for k, v in six.iteritems(self.kwargs):
+        for k, v in self.kwargs.items():
             # save those values in the dict prev_values that will be changed
             # so that they can be recovered
             self.prev_values[k] = getattr(self.database_entry, k)
             setattr(self.database_entry, k, v)
 
     def undo(self):
-        for k, v in six.iteritems(self.prev_values):
+        for k, v in self.prev_values.items():
             setattr(self.database_entry, k, v)
 
     def __repr__(self):
-        return '<EditEntry(kwargs {0!r}, entry id {1})>'.format(
+        return '<EditEntry(kwargs {!r}, entry id {})>'.format(
             self.kwargs, self.database_entry.id)
 
 
@@ -230,7 +218,7 @@ class AddTag(DatabaseOperation):
                 pass
 
     def __repr__(self):
-        return "<AddTag(tag '{0}', session {1!r}, entry id {2})>".format(
+        return "<AddTag(tag '{}', session {!r}, entry id {})>".format(
             self.tag, self.session, self.database_entry.id)
 
 
@@ -280,11 +268,11 @@ class RemoveTag(DatabaseOperation):
                 self.database_entry.tags.append(self.tag)
 
     def __repr__(self):
-        return "<RemoveTag(tag '{0}', session {1!r}, entry id {2})>".format(
+        return "<RemoveTag(tag '{}', session {!r}, entry id {})>".format(
             self.tag, self.session, self.database_entry.id)
 
 
-class CommandManager(object):
+class CommandManager:
     """The CommandManager saves all executed and reverted commands to act as an
     undo-redo-manager. All executed commands are saved in the list attribute
     ``undo_commands`` and all undone commands are saved in the list attribute
