@@ -3,8 +3,6 @@
 # This module was developed with funding provided by
 # the Google Summer of Code (2013).
 
-from __future__ import absolute_import, print_function
-
 import itertools
 import operator
 from datetime import datetime
@@ -25,8 +23,6 @@ from sunpy.database.attrs import walker
 from sunpy.net.hek2vso import H2VClient
 from sunpy.net.attr import and_
 from sunpy.net.vso import VSOClient
-from sunpy.extern.six.moves import range
-from sunpy.util import deprecated
 
 __authors__ = ['Simon Liedtke', 'Rajul Srivastava']
 __emails__ = [
@@ -45,7 +41,7 @@ class EntryNotFoundError(Exception):
         self.entry_id = entry_id
 
     def __str__(self):  # pragma: no cover
-        return 'an entry with the ID {0:d} does not exist'.format(
+        return 'an entry with the ID {:d} does not exist'.format(
             self.entry_id)
 
 
@@ -60,7 +56,7 @@ class EntryAlreadyAddedError(Exception):
 
     def __str__(self):  # pragma: no cover
         return (
-            'the entry {0!r} was already added '
+            'the entry {!r} was already added '
             'to the database'.format(self.database_entry))
 
 
@@ -76,7 +72,7 @@ class EntryAlreadyStarredError(Exception):
 
     def __str__(self):  # pragma: no cover
         return (
-            'the entry {0!r} is already marked '
+            'the entry {!r} is already marked '
             'as starred'.format(self.database_entry))
 
 
@@ -91,7 +87,7 @@ class EntryAlreadyUnstarredError(Exception):
 
     def __str__(self):  # pragma: no cover
         return (
-            'the entry {0!r} is already not marked '
+            'the entry {!r} is already not marked '
             'as starred'.format(self.database_entry))
 
 
@@ -105,7 +101,7 @@ class NoSuchTagError(Exception):
         self.tag_name = tag_name
 
     def __str__(self):  # pragma: no cover
-        return 'the tag {0!r} is not saved in the database'.format(
+        return 'the tag {!r} is not saved in the database'.format(
             self.tag_name)
 
 
@@ -199,7 +195,7 @@ def disable_undo(database):
     database._enable_history = True
 
 
-class Database(object):
+class Database:
     """
     Database(url[, CacheClass[, cache_size[, default_waveunit]]])
 
@@ -384,17 +380,13 @@ class Database(object):
         """
         self.session.commit()
 
-    def _download_and_collect_entries(self, query_result, **kwargs):
-
-        client = kwargs.pop('client', None)
-        path = kwargs.pop('path', None)
-        progress = kwargs.pop('progress', False)
-        methods = kwargs.pop('methods', ('URL-FILE_Rice', 'URL-FILE'))
-        overwrite = kwargs.pop('overwrite', False)
+    def _download_and_collect_entries(self, query_result, client=None,
+                                      path=None, progress=False, methods=None,
+                                      overwrite=False, **kwargs):
 
         if kwargs:
             k, v = kwargs.popitem()
-            raise TypeError('unexpected keyword argument {0!r}'.format(k))
+            raise TypeError(f'unexpected keyword argument {k!r}')
 
         if client is None:
             client = VSOClient()
@@ -419,7 +411,7 @@ class Database(object):
         for temp in delete_entries:
             self.remove(temp)
 
-        paths = client.fetch(query_result, path).wait(progress=progress)
+        paths = client.fetch(query_result, path)
 
         for (path, block) in zip(paths, query_result):
             qr_entry = tables.DatabaseEntry._from_query_result_block(block)
@@ -446,19 +438,8 @@ class Database(object):
                 entry.download_time = datetime.utcnow()
                 yield entry
 
-    @deprecated('0.8', alternative='database.fetch()')
-    def download(self, *query, **kwargs):
-        """
-        See `~sunpy.database.Database.fetch`
-        """
-
-        return self.fetch(*query, **kwargs)
-
     def fetch(self, *query, **kwargs):
-
         """
-        fetch(*query[, path, overwrite, client, progress, methods])
-
         Check if the query has already been used to collect new data.
 
         If yes, query the database using the method
@@ -504,7 +485,7 @@ class Database(object):
         progress : `bool`, optional
             If True, displays the progress bar during file download.
         methods : `str` or iterable of `str`, optional
-            Set VSOClient download method, see`~sunpy.net.vso.VSOClient.get`
+            Set VSOClient download method, see`~sunpy.net.vso.VSOClient.fetch`
             for details.
 
         Examples
@@ -616,7 +597,7 @@ class Database(object):
         sortby = kwargs.pop('sortby', 'observation_time_start')
         if kwargs:
             k, v = kwargs.popitem()
-            raise TypeError('unexpected keyword argument {0!r}'.format(k))
+            raise TypeError(f'unexpected keyword argument {k!r}')
 
         db_entries = walker.create(and_(*query), self.session)
 
@@ -628,18 +609,11 @@ class Database(object):
 
         return sorted(db_entries, key=operator.attrgetter(sortby))
 
-    @deprecated('0.8', alternative='database.search')
-    def query(self, *query, **kwargs):
-        """
-        See `~sunpy.database.Database.search`
-        """
-        return self.search(*query, **kwargs)
-
     def get_entry_by_id(self, entry_id):
-        """Get a database entry by its unique ID number. If an entry with the
+        """
+        Get a database entry by its unique ID number. If an entry with the
         given ID does not exist, :exc:`sunpy.database.EntryNotFoundError` is
         raised.
-
         """
         try:
             return self._cache[entry_id]
@@ -900,7 +874,7 @@ class Database(object):
 
         Parameters
         ----------
-        path : string
+        path : str
             The directory where to look for FITS files.
 
         recursive : bool, optional
@@ -920,7 +894,7 @@ class Database(object):
 
         time_string_parse_format : str, optional
             Fallback timestamp format which will be passed to
-            `~datetime.datetime.strftime` if `sunpy.time.parse_time` is unable to
+            `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
             automatically read the `date-obs` metadata.
 
         """
