@@ -2,31 +2,25 @@
 #
 # This module was developed with funding provided by
 # the Google Summer of Code (2013).
-from __future__ import absolute_import, print_function
-
-from time import strptime, mktime
-from datetime import datetime
-import fnmatch
 import os
+import fnmatch
+from datetime import datetime
 
-from astropy.units import Unit, nm, equivalencies, quantity
-import astropy.table
-from sqlalchemy import Column, Integer, Float, String, DateTime, Boolean,\
-    Table, ForeignKey
+import numpy as np
+from sqlalchemy import Float, Table, Column, String, Boolean, Integer, DateTime, ForeignKey
 from sqlalchemy.orm import relationship
 from sqlalchemy.ext.declarative import declarative_base
-import numpy as np
 
-from sunpy.time import parse_time, TimeRange
-from sunpy.io import fits, file_tools as sunpy_filetools
-from sunpy.util import print_table
-from sunpy.extern.six.moves import map
-from sunpy.io.header import FileHeader
-from sunpy.extern import six
-import sunpy.net
+import astropy.table
+from astropy.time import Time
+from astropy.units import Unit, nm, quantity, equivalencies
 
+
+import sunpy
 from sunpy import config
-
+from sunpy.time import parse_time
+from sunpy.io.header import FileHeader
+from sunpy.io import fits, file_tools as sunpy_filetools
 
 TIME_FORMAT = config.get("general", "time_format")
 
@@ -68,7 +62,7 @@ class WaveunitNotFoundError(Exception):
         self.obj = obj
 
     def __str__(self):  # pragma: no cover
-        return 'the wavelength unit cannot be found in {0}'.format(self.obj) + \
+        return f'the wavelength unit cannot be found in {self.obj}' + \
                ' and default_waveunit not specified when opening the database'
 
 
@@ -83,15 +77,10 @@ class WaveunitNotConvertibleError(Exception):
 
     def __str__(self):  # pragma: no cover
         return (
-            'the waveunit {0!r} cannot be converted to an '
+            'the waveunit {!r} cannot be converted to an '
             'astropy.units.Unit instance'.format(self.waveunit))
 
 
-# TODO: move this function outside this package (sunpy.util? sunpy.time?)
-def timestamp2datetime(format, string):
-    return datetime.fromtimestamp(mktime(strptime(string, format)))
-
-
 class JSONDump(Base):
     __tablename__ = 'jsondumps'
 
@@ -110,7 +99,7 @@ class JSONDump(Base):
         return self.dump
 
     def __repr__(self):  # pragma: no cover
-        return '<{0}(dump {1!r})>'.format(self.__class__.__name__, self.dump)
+        return f'<{self.__class__.__name__}(dump {self.dump!r})>'
 
 
 class FitsHeaderEntry(Base):
@@ -132,13 +121,13 @@ class FitsHeaderEntry(Base):
             self.value == other.value)
 
     def __hash__(self):
-        return super(FitsHeaderEntry, self).__hash__()
+        return super().__hash__()
 
     def __ne__(self, other):
         return not (self == other)
 
     def __repr__(self):  # pragma: no cover
-        return '<{0}(id {1}, key {2!r}, value {3!r})>'.format(
+        return '<{}(id {}, key {!r}, value {!r})>'.format(
             self.__class__.__name__, self.id, self.key, self.value)
 
 
@@ -161,17 +150,17 @@ class FitsKeyComment(Base):
             self.value == other.value)
 
     def __lt__(self, other):
-        return ('{0}, {1}'.format(self.key, self.value) <
-                '{0}, {1}'.format(other.key, other.value))
+        return (f'{self.key}, {self.value}' <
+                f'{other.key}, {other.value}')
 
     def __hash__(self):
-        return super(FitsKeyComment, self).__hash__()
+        return super().__hash__()
 
     def __ne__(self, other):
         return not (self == other)
 
     def __repr__(self):  # pragma: no cover
-        return '<{0}(id {1}, key {2!r}, value {3!r})>'.format(
+        return '<{}(id {}, key {!r}, value {!r})>'.format(
             self.__class__.__name__, self.id, self.key, self.value)
 
 
@@ -187,7 +176,7 @@ class Tag(Base):
         return self.name == other.name
 
     def __hash__(self):
-        return super(Tag, self).__hash__()
+        return super().__hash__()
 
     def __ne__(self, other):
         return not (self == other)
@@ -196,7 +185,7 @@ class Tag(Base):
         return self.name
 
     def __repr__(self):  # pragma: no cover
-        return '<{0}(name {1!r})>'.format(self.__class__.__name__, self.name)
+        return f'<{self.__class__.__name__}(name {self.name!r})>'
 
 
 class DatabaseEntry(Base):
@@ -212,14 +201,14 @@ class DatabaseEntry(Base):
     id : int
         A unique ID number. By default it is None, but automatically set to the
         maximum number plus one when this entry is added to the database.
-    source : string
+    source : str
         The source is the name of an observatory or the name of a network of
         observatories.
-    provider : string
+    provider : str
         The name of the server which provides the retrieved data.
-    physobs : string
+    physobs : str
         A physical observable identifier used by VSO.
-    fileid : string
+    fileid : str
         The file ID is a string defined by the data provider that should point
         to a specific data product. The association of fileid to the specific
         data may change sometime, if the fileid always points to the latest
@@ -228,7 +217,7 @@ class DatabaseEntry(Base):
         The date and time when the observation of the data started.
     observation_time_end : datetime
         The date and time when the observation of the data ended.
-    instrument : string
+    instrument : str
         The instrument which was used to observe the data.
     size : float
         The size of the data in kilobytes.
@@ -241,7 +230,7 @@ class DatabaseEntry(Base):
     hdu_index : int
         This value provides a list of all available HDUs and in what
         files they are located.
-    path : string
+    path : str
         A local file path where the according FITS file is saved.
     download_time : datetime
         The date and time when the files connected to a query have been
@@ -304,27 +293,27 @@ class DatabaseEntry(Base):
         ...     vso.attrs.Instrument('eit'))  # doctest: +REMOTE_DATA
         >>> entry = DatabaseEntry._from_query_result_block(qr[0])  # doctest: +REMOTE_DATA
         >>> entry.source  # doctest: +REMOTE_DATA
-        SOHO
+        'SOHO'
         >>> entry.provider  # doctest: +REMOTE_DATA
-        SDAC
+        'SDAC'
         >>> entry.physobs  # doctest: +REMOTE_DATA
         'intensity'
         >>> entry.fileid  # doctest: +REMOTE_DATA
-        /archive/soho/private/data/processed/eit/lz/2001/01/efz20010101.000042
+        '/archive/soho/private/data/processed/eit/lz/2001/01/efz20010101.000042'
         >>> entry.observation_time_start, entry.observation_time_end  # doctest: +REMOTE_DATA
         (datetime.datetime(2001, 1, 1, 0, 0, 42), datetime.datetime(2001, 1, 1, 0, 0, 54))
         >>> entry.instrument  # doctest: +REMOTE_DATA
-        EIT
+        'EIT'
         >>> entry.size  # doctest: +REMOTE_DATA
         2059.0
         >>> entry.wavemin, entry.wavemax  # doctest: +REMOTE_DATA
         (19.5, 19.5)
 
         """
-        time_start = timestamp2datetime('%Y%m%d%H%M%S', qr_block.time.start)
+        time_start = datetime.strptime(qr_block.time.start, '%Y%m%d%H%M%S')
         if not qr_block.time.end:
             qr_block.time.end = qr_block.time.start
-        time_end = timestamp2datetime('%Y%m%d%H%M%S', qr_block.time.end)
+        time_end = datetime.strptime(qr_block.time.end, '%Y%m%d%H%M%S')
         wave = qr_block.wave
         unit = None
         if wave.waveunit is None:
@@ -390,8 +379,8 @@ class DatabaseEntry(Base):
         if physobs is not None:
             physobs = str(physobs)
         instrument = getattr(sr_block, 'instrument', None)
-        time_start = sr_block.time.start
-        time_end = sr_block.time.end
+        time_start = sr_block.time.start.datetime
+        time_end = sr_block.time.end.datetime
 
         wavelengths = getattr(sr_block, 'wave', None)
         wavelength_temp = {}
@@ -486,7 +475,7 @@ class DatabaseEntry(Base):
         return True
 
     def __hash__(self):
-        return super(DatabaseEntry, self).__hash__()
+        return super().__hash__()
 
     def __ne__(self, other):  # pragma: no cover
         return not (self == other)
@@ -497,11 +486,11 @@ class DatabaseEntry(Base):
             'observation_time_start', 'observation_time_end', 'instrument',
             'size', 'wavemin', 'wavemax', 'path', 'download_time', 'starred',
             'fits_header_entries', 'tags']
-        ret = '<{0}('.format(self.__class__.__name__)
+        ret = f'<{self.__class__.__name__}('
         for attr in attrs:
             value = getattr(self, attr, None)
             if value:
-                ret += '{0} {1!r}, '.format(attr, value)
+                ret += f'{attr} {value!r}, '
         ret = ret.rstrip(', ')
         ret += ')>'
         return ret
@@ -532,17 +521,17 @@ def entries_from_query_result(qr, default_waveunit=None):
     >>> entries = entries_from_query_result(qr)  # doctest: +REMOTE_DATA
     >>> entry = next(entries)  # doctest: +REMOTE_DATA
     >>> entry.source  # doctest: +REMOTE_DATA
-    SOHO
+    'SOHO'
     >>> entry.provider  # doctest: +REMOTE_DATA
-    SDAC
+    'SDAC'
     >>> entry.physobs  # doctest: +REMOTE_DATA
     'intensity'
     >>> entry.fileid  # doctest: +REMOTE_DATA
-    /archive/soho/private/data/processed/eit/lz/2001/01/efz20010101.000042
+    '/archive/soho/private/data/processed/eit/lz/2001/01/efz20010101.000042'
     >>> entry.observation_time_start, entry.observation_time_end  # doctest: +REMOTE_DATA
     (datetime.datetime(2001, 1, 1, 0, 0, 42), datetime.datetime(2001, 1, 1, 0, 0, 54))
     >>> entry.instrument  # doctest: +REMOTE_DATA
-    EIT
+    'EIT'
     >>> entry.size  # doctest: +REMOTE_DATA
     2059.0
     >>> entry.wavemin, entry.wavemax  # doctest: +REMOTE_DATA
@@ -610,7 +599,9 @@ def entries_from_fido_search_result(sr, default_waveunit=None):
 
 
 def entries_from_file(file, default_waveunit=None,
-                      time_string_parse_format=None):
+                      time_string_parse_format=''):
+    # Note: time_string_parse_format='' so that None won't be passed to Time.strptime
+    # (which would make strptime freak out, if I remember correctly).
     """Use the headers of a FITS file to generate an iterator of
     :class:`sunpy.database.tables.DatabaseEntry` instances. Gathered
     information will be saved in the attribute `fits_header_entries`. If the
@@ -634,7 +625,7 @@ def entries_from_file(file, default_waveunit=None,
 
     time_string_parse_format : str, optional
         Fallback timestamp format which will be passed to
-        `~datetime.datetime.strftime` if `sunpy.time.parse_time` is unable to
+        `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
         automatically read the `date-obs` metadata.
 
     Raises
@@ -668,26 +659,27 @@ def entries_from_file(file, default_waveunit=None,
 
     """
     headers = fits.get_header(file)
+
     # This just checks for blank default headers
     # due to compression.
     for header in headers:
         if header == DEFAULT_HEADER:
             headers.remove(header)
 
-    if isinstance(file, (str, six.text_type)):
+    if isinstance(file, str):
         filename = file
     else:
         filename = getattr(file, 'name', None)
     for header in headers:
         entry = DatabaseEntry(path=filename)
-        for key, value in six.iteritems(header):
+        for key, value in header.items():
             # Yes, it is possible to have an empty key in a FITS file.
             # Example: sunpy.data.sample.EIT_195_IMAGE
             # Don't ask me why this could be a good idea.
             if key == '':
                 value = str(value)
             elif key == 'KEYCOMMENTS':
-                for k, v in six.iteritems(value):
+                for k, v in value.items():
                     entry.fits_key_comments.append(FitsKeyComment(k, v))
                 continue
             entry.fits_header_entries.append(FitsHeaderEntry(key, value))
@@ -714,15 +706,17 @@ def entries_from_file(file, default_waveunit=None,
             # NOTE: the key DATE-END or DATE_END is not part of the official
             # FITS standard, but many FITS files use it in their header
             elif key in ('DATE-END', 'DATE_END'):
-                entry.observation_time_end = parse_time(
-                    value,
-                    _time_string_parse_format=time_string_parse_format
-                )
+                try:
+                    dt = parse_time(value).datetime
+                except ValueError:
+                    dt = Time.strptime(value, time_string_parse_format).datetime
+                entry.observation_time_end = dt
             elif key in ('DATE-OBS', 'DATE_OBS'):
-                entry.observation_time_start = parse_time(
-                    value,
-                    _time_string_parse_format=time_string_parse_format
-                )
+                try:
+                    dt = parse_time(value).datetime
+                except ValueError:
+                    dt = Time.strptime(value, time_string_parse_format).datetime
+                entry.observation_time_start = dt
         yield entry
 
 
@@ -736,7 +730,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
 
     Parameters
     ----------
-    fitsdir : string
+    fitsdir : str
         The directory where to look for FITS files.
 
     recursive : bool, optional
@@ -757,7 +751,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
 
     time_string_parse_format : str, optional
         Fallback timestamp format which will be passed to
-        `~datetime.datetime.strftime` if `sunpy.time.parse_time` is unable to
+        `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
         automatically read the `date-obs` metadata.
 
     Returns
@@ -780,7 +774,7 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
 
     """
     for dirpath, dirnames, filenames in os.walk(fitsdir):
-        filename_paths = (os.path.join(dirpath, name) for name in filenames)
+        filename_paths = (os.path.join(dirpath, name) for name in sorted(filenames))
         for path in fnmatch.filter(filename_paths, pattern):
             try:
                 filetype = sunpy_filetools._detect_filetype(path)
