@@ -1,27 +1,31 @@
-from __future__ import absolute_import, division, print_function
-# Author: Tomas Meszaros <exo@tty.sk>
+import os
+
+import numpy as np
+import pytest
 
 import astropy.units as u
-from sunpy.image.rescale import reshape_image_to_4d_superpixel
-import pytest
-import os
-import numpy as np
+
 import sunpy.data.test
 import sunpy.map
+from sunpy.image.resample import reshape_image_to_4d_superpixel
+
 
 @pytest.fixture
 def aia171_test_map():
     testpath = sunpy.data.test.rootdir
     return sunpy.map.Map(os.path.join(testpath, 'aia_171_level1.fits'))
 
+
 @pytest.fixture
 def shape(aia171_test_map):
     return np.array(aia171_test_map.data.shape)
 
+
 def resample_meta(aia171_test_map, dimensions, method, center, minusone):
     map_resampled = aia171_test_map.resample(dimensions)
     return tuple(map_resampled.data.shape)
 
+
 def resample_method(aia171_test_map, method):
     assert resample_meta(aia171_test_map, (512, 512) * u.pix, method, False, False) == (512, 512)
     assert resample_meta(aia171_test_map, (2056, 2056) * u.pix, method, False, False) == (2056, 2056)
@@ -32,18 +36,23 @@ def resample_method(aia171_test_map, method):
     assert resample_meta(aia171_test_map, (512, 512) * u.pix, method, True, True) == (512, 512)
     assert resample_meta(aia171_test_map, (2056, 2056) * u.pix, method, True, True) == (2056, 2056)
 
+
 def test_resample_neighbor(aia171_test_map):
     resample_method(aia171_test_map, 'neighbor')
 
+
 def test_resample_nearest(aia171_test_map):
     resample_method(aia171_test_map, 'nearest')
 
+
 def test_resample_linear(aia171_test_map):
     resample_method(aia171_test_map, 'linear')
 
+
 def test_resample_spline(aia171_test_map):
     resample_method(aia171_test_map, 'spline')
 
+
 def test_reshape(aia171_test_map, shape):
 
     def _n(a, b, c):
