@@ -2,7 +2,7 @@
 The Interface Region Imaging Spectrometer (IRIS) instrument routines.
 
 Currently this module only includes a simple hack to convert SJI mode files to
-a `sunpy.map.MapCube` instance.
+a `sunpy.map.MapSequence` instance.
 
 .. note::
 
