@@ -6,12 +6,12 @@ import sunpy.io
 import sunpy.time
 import sunpy.map
 
-__all__ = ['SJI_to_cube']
+__all__ = ['SJI_to_sequence']
 
 
-def SJI_to_cube(filename, start=0, stop=None, hdu=0):
+def SJI_to_sequence(filename, start=0, stop=None, hdu=0):
     """
-    Read a SJI file and return a MapCube
+    Read a SJI file and return a MapSequence
 
     .. warning::
         This function is a very early beta and is not stable. Further work is
@@ -19,21 +19,21 @@ def SJI_to_cube(filename, start=0, stop=None, hdu=0):
 
     Parameters
     ----------
-    filename: string
+    filename: str
         File to read
 
     start: int
-        Temporal axis index to create MapCube from
+        Temporal axis index to create MapSequence from
 
     stop: int
-        Temporal index to stop MapCube at
+        Temporal index to stop MapSequence at
 
     hdu: int
         Choose hdu index
 
     Returns
     -------
-    iris_cube: sunpy.map.MapCube
+    iris_cube: sunpy.map.MapSequence
         A map cube of the SJI sequence
     """
 
@@ -46,14 +46,14 @@ def SJI_to_cube(filename, start=0, stop=None, hdu=0):
     if not stop:
         stop = len(splits)
 
-    headers = [hdus[hdu][1]]*(stop-start)
+    headers = [hdus[hdu][1]] * (stop - start)
     datas = hdus[hdu][0][start:stop]
 
     # Make the cube:
-    iris_cube = sunpy.map.Map(list(zip(datas, headers)), cube=True)
+    iris_cube = sunpy.map.Map(list(zip(datas, headers)), sequence=True)
     # Set the date/time
 
     for i, m in enumerate(iris_cube):
-        m.meta['DATE-OBS'] = splits[i].center.isoformat()
+        m.meta['DATE-OBS'] = splits[i].center.isot
 
     return iris_cube
