@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division
-
 import tempfile
 import os.path
 import pytest
@@ -8,20 +6,21 @@ import datetime
 import numpy as np
 import pandas
 
+from astropy.time import TimeDelta
+import astropy.units as u
+
 from sunpy.data.test import rootdir
-from sunpy.time import parse_time
-from sunpy import lightcurve
+from sunpy.time import parse_time, is_time_equal
 from sunpy import timeseries
 from sunpy.instr import lyra
 
-from sunpy.extern.six.moves import range
 
 # Define location for test LYTAF database files
 TEST_DATA_PATH = rootdir
 
 # Define some test data for test_remove_lytaf_events()
-TIME = np.array([datetime.datetime(2013, 2, 1) + datetime.timedelta(minutes=i)
-                 for i in range(120)])
+TIME = parse_time(np.array([datetime.datetime(2013, 2, 1) + datetime.timedelta(minutes=i)
+                  for i in range(120)]))
 CHANNELS = [np.zeros(len(TIME)) + 0.4, np.zeros(len(TIME)) + 0.1]
 EMPTY_LYTAF = np.empty((0,), dtype=[("insertion_time", object),
                                     ("begin_time", object),
@@ -31,18 +30,18 @@ EMPTY_LYTAF = np.empty((0,), dtype=[("insertion_time", object),
                                     ("event_definition", object)])
 LYTAF_TEST = np.append(
     EMPTY_LYTAF,
-    np.array([(datetime.datetime.utcfromtimestamp(1371459961),
-               datetime.datetime.utcfromtimestamp(1359677220),
-               datetime.datetime.utcfromtimestamp(1359677250),
-               datetime.datetime.utcfromtimestamp(1359677400),
+    np.array([(parse_time(datetime.datetime.utcfromtimestamp(1371459961)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359677220)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359677250)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359677400)),
                "LAR", "Large Angle Rotation.")],
              dtype=EMPTY_LYTAF.dtype))
 LYTAF_TEST = np.append(
     LYTAF_TEST,
-    np.array([(datetime.datetime.utcfromtimestamp(1371460063),
-               datetime.datetime.utcfromtimestamp(1359681764),
-               datetime.datetime.utcfromtimestamp(1359682450),
-               datetime.datetime.utcfromtimestamp(1359683136),
+    np.array([(parse_time(datetime.datetime.utcfromtimestamp(1371460063)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359681764)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359682450)),
+               parse_time(datetime.datetime.utcfromtimestamp(1359683136)),
                "UV occ.", "Occultation in the UV spectrum.")],
              dtype=LYTAF_TEST.dtype))
 
@@ -58,7 +57,7 @@ def test_split_series_using_lytaf():
     # construct a dummy signal for testing purposes
     basetime = parse_time('2010-06-13 02:00')
     seconds = 3600
-    dummy_time = [basetime + datetime.timedelta(0, s) for s in range(seconds)]
+    dummy_time = [basetime + TimeDelta(s*u.second) for s in range(seconds)]
     dummy_data = np.random.random(seconds)
 
     lytaf_tmp = lyra.get_lytaf_events('2010-06-13 02:00', '2010-06-13 06:00',
@@ -67,10 +66,10 @@ def test_split_series_using_lytaf():
     split = lyra.split_series_using_lytaf(dummy_time, dummy_data, lytaf_tmp)
     assert type(split) == list
     assert len(split) == 4
-    assert split[0]['subtimes'][0] == datetime.datetime(2010, 6, 13, 2, 0)
-    assert split[0]['subtimes'][-1] == datetime.datetime(2010, 6, 13, 2, 7, 2)
-    assert split[3]['subtimes'][0] == datetime.datetime(2010, 6, 13, 2, 59, 41)
-    assert split[3]['subtimes'][-1] == datetime.datetime(2010, 6, 13, 2, 59, 58)
+    assert is_time_equal(split[0]['subtimes'][0], parse_time((2010, 6, 13, 2, 0)))
+    assert is_time_equal(split[0]['subtimes'][-1], parse_time((2010, 6, 13, 2, 7, 2)))
+    assert is_time_equal(split[3]['subtimes'][0], parse_time((2010, 6, 13, 2, 59, 42)))
+    assert is_time_equal(split[3]['subtimes'][-1], parse_time((2010, 6, 13, 2, 59, 58)))
 
     # Test case when no LYTAF events found in time series.
     split_no_lytaf = lyra.split_series_using_lytaf(dummy_time,
@@ -82,33 +81,23 @@ def test_split_series_using_lytaf():
     assert split_no_lytaf[0]["subdata"].all() == dummy_data.all()
 
 
-def get_lyradata(dtype):
-    if dtype == 'lc':
-        # Create sample LYRALightCurve
-        lyrats = lightcurve.LYRALightCurve.create("2014-01-01")
-        lyrats.data = pandas.DataFrame(index=TIME,
-                                       data={"CHANNEL1": CHANNELS[0],
-                                             "CHANNEL2": CHANNELS[1],
-                                             "CHANNEL3": CHANNELS[0],
-                                             "CHANNEL4": CHANNELS[1]})
-    else:
-        # Create sample TimeSeries
-        lyrats = timeseries.TimeSeries(
-            os.path.join(rootdir, 'lyra_20150101-000000_lev3_std_truncated.fits.gz'),
-            source='LYRA')
-        lyrats.data = pandas.DataFrame(index=TIME,
-                                       data={"CHANNEL1": CHANNELS[0],
-                                             "CHANNEL2": CHANNELS[1],
-                                             "CHANNEL3": CHANNELS[0],
-                                             "CHANNEL4": CHANNELS[1]})
+@pytest.fixture
+def lyra_ts():
+    # Create sample TimeSeries
+    lyrats = timeseries.TimeSeries(
+        os.path.join(rootdir, 'lyra_20150101-000000_lev3_std_truncated.fits.gz'),
+        source='LYRA')
+    lyrats.data = pandas.DataFrame(index=TIME,
+                                   data={"CHANNEL1": CHANNELS[0],
+                                         "CHANNEL2": CHANNELS[1],
+                                         "CHANNEL3": CHANNELS[0],
+                                         "CHANNEL4": CHANNELS[1]})
     return lyrats
 
 
 @pytest.mark.remote_data
-@pytest.mark.parametrize('dtype', ['ts', 'lc'])
-def test_remove_lytaf_events_from_timeseries(dtype):
-    """Test if artefacts are correctly removed from a TimeSeries.
-    Also test LYRALightCurve for backwards compatibility."""
+def test_remove_lytaf_events_from_timeseries(lyra_ts):
+    """Test if artefacts are correctly removed from a TimeSeries."""
     # Check correct errors are raised due to bad input
     with pytest.raises(AttributeError):
         ts_test = lyra.remove_lytaf_events_from_timeseries(
@@ -116,18 +105,17 @@ def test_remove_lytaf_events_from_timeseries(dtype):
 
     # Run remove_artifacts_from_timeseries, returning artifact
     # status
-    ts = get_lyradata(dtype)
     ts_test, artifact_status_test = \
         lyra.remove_lytaf_events_from_timeseries(
-            ts, artifacts=["LAR", "Offpoint"], return_artifacts=True,
+            lyra_ts, artifacts=["LAR", "Offpoint"], return_artifacts=True,
             lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
     # Generate expected data by calling _remove_lytaf_events and
     # constructing expected dataframe manually.
     time, channels, artifact_status_expected = lyra._remove_lytaf_events(
-        ts.data.index, channels=[np.asanyarray(ts.data["CHANNEL1"]),
-                                 np.asanyarray(ts.data["CHANNEL2"]),
-                                 np.asanyarray(ts.data["CHANNEL3"]),
-                                 np.asanyarray(ts.data["CHANNEL4"])],
+        lyra_ts.data.index, channels=[np.asanyarray(lyra_ts.data["CHANNEL1"]),
+                                      np.asanyarray(lyra_ts.data["CHANNEL2"]),
+                                      np.asanyarray(lyra_ts.data["CHANNEL3"]),
+                                      np.asanyarray(lyra_ts.data["CHANNEL4"])],
         artifacts=["LAR", "Offpoint"], return_artifacts=True,
         lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
     dataframe_expected = pandas.DataFrame(index=time,
@@ -151,7 +139,7 @@ def test_remove_lytaf_events_from_timeseries(dtype):
     # artifact status
     ts_test = \
         lyra.remove_lytaf_events_from_timeseries(
-            ts, artifacts=["LAR", "Offpoint"],
+            lyra_ts, artifacts=["LAR", "Offpoint"],
             lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
     # Assert expected result is returned
     pandas.util.testing.assert_frame_equal(ts_test.data, dataframe_expected)
@@ -213,11 +201,12 @@ def test_remove_lytaf_events_1():
 def test_remove_lytaf_events_2():
     """Test _remove_lytaf_events() with no user artifacts found."""
     # Run _remove_lytaf_events
-    time_test, channels_test, artifacts_status_test = \
-        lyra._remove_lytaf_events(
-            TIME, channels=CHANNELS, artifacts="Offpoint",
-            return_artifacts=True, lytaf_path=TEST_DATA_PATH,
-            force_use_local_lytaf=True)
+    with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
+        time_test, channels_test, artifacts_status_test = \
+            lyra._remove_lytaf_events(
+                TIME, channels=CHANNELS, artifacts="Offpoint",
+                return_artifacts=True, lytaf_path=TEST_DATA_PATH,
+                force_use_local_lytaf=True)
     # Generated expected result
     time_expected = TIME
     channels_expected = CHANNELS
@@ -225,7 +214,7 @@ def test_remove_lytaf_events_2():
                                  "not_removed": LYTAF_TEST,
                                  "not_found": ["Offpoint"]}
     # Assert test values are same as expected
-    assert time_test.all() == time_expected.all()
+    assert np.all(time_test == time_expected)
     assert (channels_test[0]).all() == (channels_expected[0]).all()
     assert (channels_test[1]).all() == (channels_expected[1]).all()
     assert artifacts_status_test.keys() == artifacts_status_expected.keys()
@@ -242,18 +231,20 @@ def test_remove_lytaf_events_2():
     # supplied.
     # Case 1: channels kwarg is True
     # Run _remove_lytaf_events
-    time_test, channels_test = lyra._remove_lytaf_events(
-        TIME, channels=CHANNELS, artifacts=["Offpoint"],
-        lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
-    assert time_test.all() == time_expected.all()
+    with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
+        time_test, channels_test = lyra._remove_lytaf_events(
+            TIME, channels=CHANNELS, artifacts=["Offpoint"],
+            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+    assert np.all(time_test == time_expected)
     assert (channels_test[0]).all() == (channels_expected[0]).all()
     assert (channels_test[1]).all() == (channels_expected[1]).all()
     # Case 2: channels kwarg is False
     # Run _remove_lytaf_events
-    time_test = lyra._remove_lytaf_events(
-        TIME, artifacts=["Offpoint"],
-        lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
-    assert time_test.all() == time_expected.all()
+    with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
+        time_test = lyra._remove_lytaf_events(
+            TIME, artifacts=["Offpoint"],
+            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+    assert np.all(time_test == time_expected)
 
 
 def test_remove_lytaf_events_3():
@@ -316,16 +307,16 @@ def test_get_lytaf_events():
                 datetime.datetime.utcfromtimestamp(1368583080),
                 datetime.datetime.utcfromtimestamp(1371050025),
                 datetime.datetime.utcfromtimestamp(1371167100)]
-    event_type = [u"LAR", u"UV occ.", u"Vis LED on", u"M Flare", u"UV LED on",
-                  u"X Flare", u"Off-limb event", u"Unexplained feature"]
-    event_description = [u"Large Angle Rotation.",
-                         u"Occultation in the UV spectrum.",
-                         u"Visual LED is turned on.",
-                         u"M class solar flare.",
-                         u"UV LED is turned on.",
-                         u"X class solar flare.",
-                         u"Off-limb event in SWAP.",
-                         u"Unexplained feature."]
+    event_type = ["LAR", "UV occ.", "Vis LED on", "M Flare", "UV LED on",
+                  "X Flare", "Off-limb event", "Unexplained feature"]
+    event_description = ["Large Angle Rotation.",
+                         "Occultation in the UV spectrum.",
+                         "Visual LED is turned on.",
+                         "M class solar flare.",
+                         "UV LED is turned on.",
+                         "X class solar flare.",
+                         "Off-limb event in SWAP.",
+                         "Unexplained feature."]
     lytaf_expected = np.empty((8,), dtype=[("insertion_time", object),
                                            ("begin_time", object),
                                            ("reference_time", object),
@@ -369,6 +360,7 @@ def test_prep_columns():
     """Test whether _prep_columns correctly prepares data."""
     # Generate simple input data
     time_input = TIME[0:2]
+    time_input.precision = 9
     channels_input = [CHANNELS[0][0:2], CHANNELS[1][0:2]]
     filecolumns_input = ["time", "channel0", "channel1"]
 
@@ -376,8 +368,7 @@ def test_prep_columns():
     string_time_test, filecolumns_test = lyra._prep_columns(
         time_input, channels_input, filecolumns_input)
     # Generate expected output and verify _prep_columns() works
-    string_time_expected = np.array([t.strftime("%Y-%m-%dT%H:%M:%S.%f")
-                                     for t in time_input])
+    string_time_expected = np.array(time_input.isot)
     filecolumns_expected = ["time", "channel0", "channel1"]
     np.testing.assert_array_equal(string_time_test, string_time_expected)
     assert filecolumns_test == filecolumns_expected
