@@ -1,64 +1,55 @@
 """
-FITS File Reader
+This module provides a FITS file reader.
 
 Notes
 -----
-FITS
-    [1] FITS files allow comments to be attached to every value in the header.
-    This is implemented in this module as a KEYCOMMENTS dictionary in the
-    sunpy header. To add a comment to the file on write, add a comment to this
-    dictionary with the same name as a key in the header (upcased).
 
-    [2] Due to the way `~astropy.io.fits` works with images the header dictionary may
-    differ depending on whether is accessed before or after the fits[0].data
-    is requested. If the header is read before the data then the original
-    header will be returned. If the header is read after the data has been
-    accessed then the data will have been scaled and a modified header
-    reflecting these changes will be returned: BITPIX may differ and
-    BSCALE and B_ZERO may be dropped in the modified version.
+1. FITS files allow comments to be attached to every value in the header.
+   This is implemented in this module as a KEYCOMMENTS dictionary in the
+   sunpy header. To add a comment to the file on write, add a comment to this
+   dictionary with the same name as a key in the header (upcased).
 
-    [3] The verify('fix') call attempts to handle violations of the FITS
-    standard. For example, nan values will be converted to "nan" strings.
-    Attempting to cast a pyfits header to a dictionary while it contains
-    invalid header tags will result in an error so verifying it early on
-    makes the header easier to work with later.
+2. Due to the way `~astropy.io.fits` works with images, the header dictionary may
+   differ depending on whether is accessed before or after the fits[0].data
+   is requested. If the header is read before the data then the original
+   header will be returned. If the header is read after the data has been
+   accessed then the data will have been scaled and a modified header
+   reflecting these changes will be returned: BITPIX may differ and
+   BSCALE and B_ZERO may be dropped in the modified version.
 
-References
-----------
-| https://stackoverflow.com/questions/456672/class-factory-in-python
+3. The verify('silentfix+warn') call attempts to handle violations of the FITS
+   standard. For example, ``nan`` values will be converted to "nan" strings.
+   Attempting to cast a `astropy.io.fits.Header` to a dictionary while it contains
+   invalid header tags will result in an error so verifying it early on
+   makes the header easier to work with later.
 """
-from __future__ import absolute_import, division, print_function
 import os
 import re
 import sys
 import warnings
 import traceback
-import itertools
 import collections
 
 from astropy.io import fits
 
 from sunpy.io.header import FileHeader
-from sunpy.extern.six.moves import zip
+from sunpy.util.exceptions import SunpyUserWarning
 
 __all__ = ['header_to_fits', 'read', 'get_header', 'write', 'extract_waveunit']
 
-__author__ = "Keith Hughitt, Stuart Mumford, Simon Liedtke"
-__email__ = "keith.hughitt@nasa.gov"
-
 HDPair = collections.namedtuple('HDPair', ['data', 'header'])
 
 
 def read(filepath, hdus=None, memmap=None, **kwargs):
     """
-    Read a fits file
+    Read a fits file.
 
     Parameters
     ----------
     filepath : `str`
-        The fits file to be read
+        The fits file to be read.
     hdu: `int` or iterable
-        The HDU indexes to read from the file
+        The HDU indexes to read from the file.
 
     Returns
     -------
@@ -69,8 +60,9 @@ def read(filepath, hdus=None, memmap=None, **kwargs):
     -----
     This routine reads all the HDU's in a fits file and returns a list of the
     data and a FileHeader instance for each one.
+
     Also all comments in the original file are concatenated into a single
-    'comment' key in the returned FileHeader.
+    "comment" key in the returned FileHeader.
     """
     with fits.open(filepath, ignore_blank=True, memmap=memmap) as hdulist:
         if hdus is not None:
@@ -88,12 +80,12 @@ def read(filepath, hdus=None, memmap=None, **kwargs):
             try:
                 pairs.append(HDPair(hdu.data, header))
             except (KeyError, ValueError) as e:
-                message = "Error when reading HDU {}. Skipping.\n".format(i)
+                message = f"Error when reading HDU {i}. Skipping.\n"
                 for line in traceback.format_tb(sys.exc_info()[2]):
                     message += line
                     message += '\n'
                 message += repr(e)
-                warnings.warn(message, Warning, stacklevel=2)
+                warnings.warn(message, SunpyUserWarning)
 
     return pairs
 
@@ -102,17 +94,17 @@ def get_header(afile):
     """
     Read a fits file and return just the headers for all HDU's. In each header,
     the key WAVEUNIT denotes the wavelength unit which is used to describe the
-    value of the key WAVELNTH.
+    value of the key "WAVELNTH".
 
     Parameters
     ----------
-    afile : `str` or fits.HDUList
+    afile : `str` or `astropy.io.fits.HDUList`
         The file to be read, or HDUList to process.
 
     Returns
     -------
     headers : `list`
-        A list of FileHeader headers.
+        A list of `sunpy.io.helper.FileHeader` headers.
     """
     if isinstance(afile, fits.HDUList):
         hdulist = afile
@@ -160,15 +152,14 @@ def write(fname, data, header, hdu_type=None, **kwargs):
     Parameters
     ----------
     fname : `str`
-        File name, with extension
+        File name, with extension.
     data : `numpy.ndarray`
-        n-dimensional data array
+        n-dimensional data array.
     header : `dict`
-        A header dictionary
-    hdu_type: `None`, `~fits.CompImageHDU`
+        A header dictionary.
+    hdu_type: `None` or `~astropy.io.fits.CompImageHDU`
         `None` will return a normal FITS files.
-        `~fits.CompImageHDU` will rice compress the FITS file.
-
+        `~astropy.io.fits.CompImageHDU` will rice compress the FITS file.
     """
     # Copy header so the one in memory is left alone while changing it for
     # write.
@@ -194,11 +185,11 @@ def write(fname, data, header, hdu_type=None, **kwargs):
 
     hdul.writeto(fname, **fitskwargs)
 
+
 def header_to_fits(header):
     """
     Convert a header dict to a `~astropy.fits.Header`.
     """
-
     # The comments need to be added to the header separately from the normal
     # kwargs. Find and deal with them:
     fits_header = fits.Header()
@@ -230,17 +221,18 @@ def header_to_fits(header):
 
         raise TypeError("KEYCOMMENTS must be a dictionary")
 
-
     return fits_header
 
+
 def extract_waveunit(header):
-    """Attempt to read the wavelength unit from a given FITS header.
+    """
+    Attempt to read the wavelength unit from a given FITS header.
 
     Parameters
     ----------
-    header : FileHeader
-        One :class:`sunpy.io.header.FileHeader` instance which was created by
-        reading a FITS file. :func:`sunpy.io.fits.get_header` returns a list of
+    header : `sunpy.io.header.FileHeader`
+        One `~sunpy.io.header.FileHeader` instance which was created by
+        reading a FITS file. For example, `sunpy.io.fits.get_header` returns a list of
         such instances.
 
     Returns
@@ -252,14 +244,13 @@ def extract_waveunit(header):
     --------
     The goal of this function is to return a string that can be used in
     conjunction with the astropy.units module so that the return value can be
-    directly passed to ``astropy.units.Unit``::
-
-        >>> import astropy.units
-        >>> header = {'WAVEUNIT': 'Angstrom', 'KEYCOMMENTS': {}}
-        >>> waveunit = extract_waveunit(header)
-        >>> if waveunit is not None:
-        ...     unit = astropy.units.Unit(waveunit)
+    directly passed to `astropy.units.Unit`.
 
+    >>> import astropy.units
+    >>> header = {'WAVEUNIT': 'Angstrom', 'KEYCOMMENTS': {}}
+    >>> waveunit = extract_waveunit(header)
+    >>> if waveunit is not None:
+    ...     unit = astropy.units.Unit(waveunit)
     """
     # algorithm: try the following procedures in the following order and return
     # as soon as a waveunit could be detected
