@@ -1,36 +1,32 @@
-"""JPEG 2000 File Reader"""
-from __future__ import absolute_import, division, print_function
-
+"""
+This module provides a JPEG 2000 file reader.
+"""
 import collections
-
 from xml.etree import cElementTree as ET
 
 from glymur import Jp2k
 
-from sunpy.util.xml import xml_to_dict
 from sunpy.io.header import FileHeader
+from sunpy.util.xml import xml_to_dict
 
 __all__ = ['read', 'get_header', 'write']
 
-__author__ = "Keith Hughitt"
-__email__ = "keith.hughitt@nasa.gov"
-
 HDPair = collections.namedtuple('HDPair', ['data', 'header'])
 
 
 def read(filepath, **kwargs):
     """
-    Reads a JPEG2000 file
+    Reads a JPEG2000 file.
 
     Parameters
     ----------
     filepath : `str`
-        The file to be read
+        The file to be read.
 
     Returns
     -------
     pairs : `list`
-        A list of (data, header) tuples
+        A list of (data, header) tuples.
     """
     header = get_header(filepath)
 
@@ -41,17 +37,17 @@ def read(filepath, **kwargs):
 
 def get_header(filepath):
     """
-    Reads the header from the file
+    Reads the header from the file.
 
     Parameters
     ----------
     filepath : `str`
-        The file to be read
+        The file to be read.
 
     Returns
     -------
     headers : list
-        A list of headers read from the file
+        A list of headers read from the file.
     """
     jp2 = Jp2k(filepath)
     xml_box = [box for box in jp2.box if box.box_id == 'xml ']
@@ -77,13 +73,15 @@ def get_header(filepath):
 
 def write(fname, data, header):
     """
-    Place holder for required file writer
+    Place holder for required file writer.
     """
-    raise NotImplementedError("No jp2 writer is implemented")
+    raise NotImplementedError("No jp2 writer is implemented.")
 
 
 def _is_float(s):
-    """Check to see if a string value is a valid float"""
+    """
+    Check to see if a string value is a valid float.
+    """
     try:
         float(s)
         return True
