@@ -1,11 +1,7 @@
-from __future__ import absolute_import
-
 import os
-import sys
 import platform
-
-from distutils.core import Extension
 from glob import glob
+from distutils.core import Extension
 
 from astropy_helpers import setup_helpers
 
@@ -29,7 +25,3 @@ def get_extensions():
 
         e = Extension('sunpy.io._pyana', **cfg)
         return [e]
-
-
-def requires_2to3():
-    return False
