@@ -1,13 +1,10 @@
-"""
-General ANA Tests
-"""
+
 import tempfile
 
 import numpy as np
 import pytest
 
 from sunpy.io import ana
-
 from sunpy.tests.helpers import skip_ana
 
 # Create a test image, store it, reread it and compare
@@ -64,18 +61,17 @@ def test_f32u():
     afilename = tempfile.NamedTemporaryFile().name
     ana.write(afilename, img_f32, 'testcase', 0)
     img_f32u_rec = ana.read(afilename)
-    assert np.sum(img_f32u_rec[0][0]- img_f32) == 0
+    assert np.sum(img_f32u_rec[0][0] - img_f32) == 0
 
 
 @skip_ana
 def test_f32c():
-    # Test if float 32 compressed functions
-    #TODO: Bug with same code. Needs to be tracked down.
-
-#        ana.write('/tmp/pyana-testf32c', img_f32, 1, 'testcase', 0)
-#        img_f32c_rec = ana.read('/tmp/pyana-testf32c', 1)
-#        assert_(np.sum(img_f32c_rec[0][1]- img_f32) == 0,
-#            msg="Storing 32 bits float data without compression failed (diff: %g)" % (1.0*np.sum(img_f32c_rec[0][1] - img_f32)))
+    # TODO: Bug with same code. Needs to be tracked down.
+    #Test if float 32 compressed functions
+    #ana.write('/tmp/pyana-testf32c', img_f32, 1, 'testcase', 0)
+    #img_f32c_rec = ana.read('/tmp/pyana-testf32c', 1)
+    #assert_(np.sum(img_f32c_rec[0][1]- img_f32) == 0,
+    #        msg="Storing 32 bits float data without compression failed (diff: %g)" % (1.0*np.sum(img_f32c_rec[0][1] - img_f32)))
     afilename = tempfile.NamedTemporaryFile().name
     with pytest.raises(RuntimeError):
         ana.write(afilename, img_f32, 'testcase', 1)
