@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import os
 import glob
 from collections import OrderedDict
@@ -9,9 +7,9 @@ import numpy as np
 import astropy.io.fits
 from astropy.wcs import WCS
 
-from sunpy.map.mapbase import GenericMap, MAP_CLASSES
+import sunpy
+from sunpy.map.mapbase import GenericMap, MapMetaValidationError
 from sunpy.map.compositemap import CompositeMap
-from sunpy.map.mapcube import MapCube
 from sunpy.map.mapsequence import MapSequence
 
 from sunpy.io.file_tools import read_file
@@ -27,9 +25,7 @@ from sunpy.util.datatype_factory_base import BasicRegistrationFactory
 from sunpy.util.datatype_factory_base import NoMatchError
 from sunpy.util.datatype_factory_base import MultipleMatchError
 from sunpy.util.datatype_factory_base import ValidationFunctionError
-from sunpy.extern import six
-
-from sunpy.extern.six.moves.urllib.request import urlopen
+from urllib.request import urlopen
 
 SUPPORTED_ARRAY_TYPES = (np.ndarray,)
 try:
@@ -42,11 +38,10 @@ __authors__ = ["Russell Hewett, Stuart Mumford"]
 __email__ = "stuart@mumford.me.uk"
 
 # Make a mock DatabaseEntry class if sqlalchemy is not installed
-
 try:
     from sunpy.database.tables import DatabaseEntry
 except ImportError:
-    class DatabaseEntry(object):
+    class DatabaseEntry:
         pass
 
 __all__ = ['Map', 'MapFactory']
@@ -54,7 +49,7 @@ __all__ = ['Map', 'MapFactory']
 
 class MapFactory(BasicRegistrationFactory):
     """
-    Map(\*args, \*\*kwargs)
+    Map(\\*args, \\*\\*kwargs)
 
     Map factory class.  Used to create a variety of Map objects.  Valid map types
     are specified by registering them with the factory.
@@ -83,15 +78,15 @@ class MapFactory(BasicRegistrationFactory):
     * data, wcs object, in tuple
 
     >>> from astropy.wcs import WCS
-    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
-    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_ROLL_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_ROLL_IMAGE)    # doctest: +REMOTE_DATA
     >>> mymap = sunpy.map.Map((data, wcs))    # doctest: +REMOTE_DATA
 
     * data, wcs object, not in tuple
 
     >>> from astropy.wcs import WCS
-    >>> wcs = WCS(sunpy.data.sample.AIA_171_IMAGE)     # doctest: +REMOTE_DATA
-    >>> data = fits.getdata(sunpy.data.sample.AIA_171_IMAGE)    # doctest: +REMOTE_DATA
+    >>> wcs = WCS(sunpy.data.sample.AIA_171_ROLL_IMAGE)     # doctest: +REMOTE_DATA
+    >>> data = fits.getdata(sunpy.data.sample.AIA_171_ROLL_IMAGE)    # doctest: +REMOTE_DATA
     >>> mymap = sunpy.map.Map(data, wcs)   # doctest: +REMOTE_DATA
 
     * File names
@@ -120,9 +115,8 @@ class MapFactory(BasicRegistrationFactory):
 
     * Any mixture of the above not in a list
 
-    >>> mymap = sunpy.map.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')  # doctest: +SKIP
-    """
-
+    >>> mymap = sunpy.map.Map(((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits'))  # doctest: +SKIP
+    """  # noqa
 
     def _read_file(self, fname, **kwargs):
         """ Read in a file name and return the list of (data, meta) pairs in
@@ -203,14 +197,14 @@ class MapFactory(BasicRegistrationFactory):
                     i += 1    # an extra increment to account for the data-header pairing
 
             # File name
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   os.path.isfile(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 pairs = self._read_file(path, **kwargs)
                 data_header_pairs += pairs
 
             # Directory
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   os.path.isdir(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 files = [os.path.join(path, elem) for elem in os.listdir(path)]
@@ -218,7 +212,7 @@ class MapFactory(BasicRegistrationFactory):
                     data_header_pairs += self._read_file(afile, **kwargs)
 
             # Glob
-            elif (isinstance(arg, six.string_types) and '*' in arg):
+            elif (isinstance(arg, str) and '*' in arg):
                 files = glob.glob(os.path.expanduser(arg))
                 for afile in files:
                     data_header_pairs += self._read_file(afile, **kwargs)
@@ -228,7 +222,7 @@ class MapFactory(BasicRegistrationFactory):
                 already_maps.append(arg)
 
             # A URL
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   _is_url(arg)):
                 url = arg
                 path = download_file(url, get_and_create_download_dir())
@@ -249,7 +243,7 @@ class MapFactory(BasicRegistrationFactory):
         # order as the input, currently they are not.
         return data_header_pairs, already_maps
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, composite=False, sequence=False, silence_errors=False, **kwargs):
         """ Method for running the factory. Takes arbitrary arguments and
         keyword arguments and passes them to a sequence of pre-registered types
         to determine which is the correct Map-type to build.
@@ -260,18 +254,17 @@ class MapFactory(BasicRegistrationFactory):
 
         Parameters
         ----------
+        composite : `bool`, optional
+            Indicates if collection of maps should be returned as a `~sunpy.map.CompositeMap`.
+            Default is `False`.
 
-        composite : boolean, optional
-            Indicates if collection of maps should be returned as a CompositeMap
+        sequence : `bool`, optional
+            Indicates if collection of maps should be returned as a `sunpy.map.MapSequence`.
+            Default is `False`.
 
-        cube : boolean, optional
-            Indicates if collection of maps should be returned as a MapCube
-
-        sequence : boolean, optional
-            Indicates if collection of maps should be returned as a MapSequence
-
-        silence_errors : boolean, optional
+        silence_errors : `bool`, optional
             If set, ignore data-header pairs which cause an exception.
+            Default is ``False``.
 
         Notes
         -----
@@ -279,19 +272,6 @@ class MapFactory(BasicRegistrationFactory):
         as `memmap` for FITS files.
         """
 
-        # Hack to get around Python 2.x not backporting PEP 3102.
-        composite = kwargs.pop('composite', False)
-
-        # MapCube Deprecation
-        cube = kwargs.pop('cube', False)
-        if cube:
-            warnings.warn('MapCube is now deprecated and renamed MapSequence. ' +
-                          'Please use the syntax Map(sequence=True) instead of Map(cube=True).',
-                          SunpyDeprecationWarning, stacklevel=2)
-
-        sequence = kwargs.pop('sequence', False)
-        silence_errors = kwargs.pop('silence_errors', False)
-
         data_header_pairs, already_maps = self._parse_args(*args, **kwargs)
 
         new_maps = list()
@@ -304,22 +284,19 @@ class MapFactory(BasicRegistrationFactory):
 
             try:
                 new_map = self._check_registered_widgets(data, meta, **kwargs)
+                new_maps.append(new_map)
             except (NoMatchError, MultipleMatchError, ValidationFunctionError):
                 if not silence_errors:
                     raise
-            except:
+            except MapMetaValidationError as e:
+                warnings.warn(f"One of the data, header pairs failed to validate with: {e}")
+            except Exception:
                 raise
 
-            new_maps.append(new_map)
-
         new_maps += already_maps
 
-        # If the list is meant to be a cube, instantiate a map cube
-        if cube:
-            with warnings.catch_warnings():
-                warnings.simplefilter("ignore", category=SunpyDeprecationWarning)
-                amapcube = MapCube(new_maps, **kwargs)
-            return amapcube
+        if not len(new_maps):
+            raise RuntimeError('No maps loaded')
 
         # If the list is meant to be a sequence, instantiate a map sequence
         if sequence:
@@ -352,7 +329,7 @@ class MapFactory(BasicRegistrationFactory):
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types identified ({0})."
+            raise MultipleMatchError("Too many candidate types identified ({})."
                                      "Specify enough keywords to guarantee unique type"
                                      "identification.".format(n_matches))
 
@@ -365,7 +342,7 @@ class MapFactory(BasicRegistrationFactory):
 def _is_url(arg):
     try:
         urlopen(arg)
-    except:
+    except Exception:
         return False
     return True
 
@@ -388,6 +365,5 @@ class NoMapsFound(ValueError):
     pass
 
 
-Map = MapFactory(default_widget_type=GenericMap,
+Map = MapFactory(registry=GenericMap._registry, default_widget_type=GenericMap,
                  additional_validation_functions=['is_datasource_for'])
-Map.registry = MAP_CLASSES
