@@ -4,10 +4,9 @@ This is where datasource specific logic is implemented. Each mission should
 have its own file with one or more classes defined. Typically, these classes
 will be subclasses of the :mod`sunpy.map.Map` class.
 """
-from __future__ import absolute_import, division, print_function
 __all__ = ['XRTMap', 'SOTMap', 'SWAPMap', 'RHESSIMap', 'AIAMap', 'HMIMap',
            'EITMap', 'LASCOMap', 'MDIMap', 'EUVIMap', 'CORMap', 'HIMap',
-           'SXTMap', 'SJIMap', 'TRACEMap', 'source_stretch']
+           'SXTMap', 'SJIMap', 'TRACEMap', 'KCorMap', 'source_stretch']
 
 from .. map_factory import Map
 
@@ -29,4 +28,6 @@ from .iris import SJIMap
 
 from .trace import TRACEMap
 
+from .mlso import KCorMap
+
 from .source_type import source_stretch, from_helioviewer_project
