@@ -1,5 +1,4 @@
 """STEREO Map subclass definitions"""
-from __future__ import absolute_import, print_function, division
 #pylint: disable=W0221,W0222,E1121
 
 __author__ = "Keith Hughitt"
@@ -10,6 +9,7 @@ import matplotlib.pyplot as plt
 
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
+import astropy.units as u
 
 from sunpy.map import GenericMap
 from sunpy.map.sources.source_type import source_stretch
@@ -35,7 +35,7 @@ class EUVIMap(GenericMap):
     def __init__(self, data, header, **kwargs):
 
         GenericMap.__init__(self, data, header, **kwargs)
-        self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
+        self._nickname = "{}-{}".format(self.detector, self.observatory[-1])
         self.plot_settings['cmap'] = plt.get_cmap('sohoeit{wl:d}'.format(wl=int(self.wavelength.value)))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
         self.meta['waveunit'] = 'Angstrom'
@@ -56,6 +56,22 @@ class EUVIMap(GenericMap):
         """
         return self.meta.get('rsun', None)
 
+    @property
+    def rsun_obs(self):
+        """
+        Radius of the sun in arcseconds as a quantity.
+
+        References
+        ----------
+        https://sohowww.nascom.nasa.gov/solarsoft/stereo/secchi/doc/FITS_keywords.pdf
+        """
+        rsun_arcseconds = self.meta.get('rsun', None)
+
+        if rsun_arcseconds is None:
+            rsun_arcseconds = super().rsun_obs
+
+        return u.Quantity(rsun_arcseconds, 'arcsec')
+
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an EUVI image"""
@@ -85,7 +101,7 @@ class CORMap(GenericMap):
 
         GenericMap.__init__(self, data, header, **kwargs)
 
-        self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
+        self._nickname = "{}-{}".format(self.detector, self.observatory[-1])
         self.plot_settings['cmap'] = plt.get_cmap('stereocor{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.5)))
 
@@ -129,7 +145,7 @@ class HIMap(GenericMap):
     def __init__(self, data, header, **kwargs):
 
         GenericMap.__init__(self, data, header, **kwargs)
-        self._nickname = "{0}-{1}".format(self.detector, self.observatory[-1])
+        self._nickname = "{}-{}".format(self.detector, self.observatory[-1])
         self.plot_settings['cmap'] = plt.get_cmap('stereohi{det!s}'.format(det=self.detector[-1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.25)))
 
