@@ -10,6 +10,8 @@ from matplotlib import colors
 
 import pytest
 
+import astropy.units as u
+
 from sunpy.map.sources.soho import EITMap
 from sunpy.map import Map
 import sunpy.data.test
@@ -17,26 +19,36 @@ import sunpy.data.test
 path = sunpy.data.test.rootdir
 fitslist = glob.glob(os.path.join(path, "EIT", "*"))
 
+
 @pytest.fixture(scope="module", params=fitslist)
 def createEIT(request):
     """Creates an EITMap from a FITS file."""
     return Map(request.param)
 
+
 # EIT Tests
 def test_fitstoEIT(createEIT):
     """Tests the creation of EITMap using FITS."""
     assert isinstance(createEIT, EITMap)
 
+
 def test_is_datasource_for(createEIT):
     """Test the is_datasource_for method of EITMap.
     Note that header data to be provided as an argument
     can be a MetaDict object."""
     assert createEIT.is_datasource_for(createEIT.data, createEIT.meta)
 
+
 def test_observatory(createEIT):
     """Tests the observatory property of the EITMap object."""
     assert createEIT.observatory == "SOHO"
 
+
 def test_measurement(createEIT):
     """Tests the measurement property of the EITMap object."""
-    assert createEIT.measurement.value in [195, 171]
\ No newline at end of file
+    assert createEIT.measurement.value in [195, 171]
+
+
+def test_rsun(createEIT):
+    """Tests the measurement property of the EITMap object."""
+    assert u.allclose(createEIT.rsun_obs, 979.0701*u.arcsec)
