@@ -1,7 +1,8 @@
-import datetime
-
 import pytest
-from hypothesis import given, example, settings, HealthCheck
+from hypothesis import given, example, settings
+
+from astropy.time import TimeDelta
+import astropy.units as u
 
 from sunpy.time.timerange import TimeRange
 from sunpy.net.vso.attrs import Time, Instrument
@@ -11,6 +12,7 @@ from sunpy.net.fido_factory import UnifiedResponse
 from sunpy.net import Fido
 from sunpy.net import attrs as a
 from sunpy.net.tests.strategies import goes_time
+from sunpy.time import parse_time, is_time_equal
 
 
 @pytest.fixture
@@ -63,7 +65,7 @@ def test_fixed_satellite(LCClient):
         assert "go13" in resp.url
 
 
-@settings(deadline=None, suppress_health_check=[HealthCheck.hung_test])
+@settings(deadline=50000)
 @example(a.Time("2006-08-01", "2006-08-01"))
 # This example tests a time range with a satellite jump and no overlap
 @example(a.Time("2009-11-30", "2009-12-3"))
@@ -73,11 +75,11 @@ def test_query(LCClient, time):
     assert isinstance(qr1, QueryResponse)
     # We only compare dates here as the start time of the qr will always be the
     # start of the day.
-    assert qr1.time_range().start.date() == time.start.date()
+    assert qr1.time_range().start.strftime('%Y-%m-%d') == time.start.strftime('%Y-%m-%d')
 
-    almost_day = datetime.timedelta(days=1, milliseconds=-1)
-    end = datetime.datetime.combine(time.end.date(), datetime.time()) + almost_day
-    assert qr1.time_range().end == end
+    almost_day = TimeDelta(1*u.day - 1*u.millisecond)
+    end = parse_time(time.end.strftime('%Y-%m-%d')) + almost_day
+    assert is_time_equal(qr1.time_range().end, end)
 
 
 def test_query_error(LCClient):
@@ -94,16 +96,14 @@ def test_query_error(LCClient):
 ])
 def test_get(LCClient, time, instrument):
     qr1 = LCClient.search(time, instrument)
-    res = LCClient.fetch(qr1)
-    download_list = res.wait(progress=False)
+    download_list = LCClient.fetch(qr1)
     assert len(download_list) == len(qr1)
 
 
 @pytest.mark.remote_data
 def test_new_logic(LCClient):
     qr = LCClient.search(Time('2012/10/4', '2012/10/6'), Instrument('XRS'))
-    res = LCClient.fetch(qr)
-    download_list = res.wait(progress=False)
+    download_list = LCClient.fetch(qr)
     assert len(download_list) == len(qr)
 
 
@@ -118,11 +118,11 @@ def test_fido(time, instrument):
     response = Fido.fetch(qr)
     assert len(response) == qr._numfile
 
-
+@settings(deadline=50000)
 @given(goes_time())
 def test_time_for_url(LCClient, time):
-    time = time.start.date().strftime("%Y/%m/%d")
-    almost_day = datetime.timedelta(days=1, milliseconds=-1)
+    time = time.start.strftime("%Y/%m/%d")
+    almost_day = TimeDelta(1*u.day - 1*u.millisecond)
 
     tr = TimeRange(time, almost_day)
     url = LCClient._get_url_for_timerange(tr)
