@@ -1,27 +1,24 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function, absolute_import
-
 import os
 import time
+import urllib
 import warnings
-from functools import partial
-from collections import Sequence
+from collections.abc import Sequence
 
+import drms
 import numpy as np
 import pandas as pd
 import astropy.units as u
 import astropy.time
 import astropy.table
 from astropy.utils.misc import isiterable
-import drms
+from parfive import Downloader, Results
 
 from sunpy import config
-from sunpy.net.download import Downloader, Results
+from sunpy.net.base_client import BaseClient
 from sunpy.net.attr import and_
 from sunpy.net.jsoc.attrs import walker
-from sunpy.extern.six.moves import urllib
-from sunpy.extern import six
-from sunpy.util import deprecated
+from sunpy.util.exceptions import SunpyUserWarning
 
 __all__ = ['JSOCClient', 'JSOCResponse']
 
@@ -30,10 +27,6 @@ PKEY_LIST_TIME = {'T_START', 'T_REC', 'T_OBS', 'MidTime', 'OBS_DATE',
                   'obsdate', 'DATE_OBS', 'starttime', 'stoptime', 'UTC_StartTime'}
 
 
-def simple_path(path, sock, url):
-    return path
-
-
 class NotExportedError(Exception):
     pass
 
@@ -79,11 +72,11 @@ class JSOCResponse(Sequence):
         """
         Returns a set of class attributes on all the response blocks.
         """
-        warnings.warn("The JSOC client does not support response block properties", UserWarning)
+        warnings.warn("The JSOC client does not support response block properties.", SunpyUserWarning)
         return set()
 
 
-class JSOCClient(object):
+class JSOCClient(BaseClient):
     """
     This is a Client to the JSOC Data Export service.
 
@@ -110,7 +103,7 @@ class JSOCClient(object):
     with JSOC beforehand `here <http://jsoc.stanford.edu/ajax/register_email.html>`_.
 
     The backend of SunPy's JSOC Client uses `drms package <https://github.com/sunpy/drms>`_.
-    The tutorials can be `found here <http://docs.sunpy.org/projects/en/stable/tutorial.html>`_.
+    The tutorials can be `found here <https://docs.sunpy.org/projects/en/stable/tutorial.html>`_.
     This can be used to build complex queries, by directly inputting the query string.
 
     Examples
@@ -123,7 +116,7 @@ class JSOCClient(object):
         >>> from sunpy.net import jsoc
         >>> from sunpy.net import attrs as a
         >>> client = jsoc.JSOCClient()
-        >>> response = client.search(a.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
+        >>> response = client.search(a.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
         ...                          a.jsoc.Series('hmi.m_45s'), a.jsoc.Notify("sunpy@sunpy.org"))  # doctest: +REMOTE_DATA
 
         The response object holds the records that your query will return:
@@ -159,7 +152,7 @@ class JSOCClient(object):
     it is used only if you need to make an export request. For example,::
 
         >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
-        >>> response = client.search(a.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
+        >>> response = client.search(a.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
         ...                          a.jsoc.Series('hmi.m_45s'))  # doctest: +REMOTE_DATA
 
     The above is a successful query operation, and will return query responses as before.
@@ -181,7 +174,7 @@ class JSOCClient(object):
         >>> from sunpy.net import jsoc
         >>> from sunpy.net import attrs as a
         >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
-        >>> response = client.search(a.jsoc.Time('2014/1/1T00:00:00', '2014/1/1T00:00:36'),
+        >>> response = client.search(a.Time('2014/1/1T00:00:00', '2014/1/1T00:00:36'),
         ...                          a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Segment('image'),
         ...                          a.jsoc.Wavelength(171*u.AA), a.jsoc.Notify("sunpy@sunpy.org"))  # doctest: +REMOTE_DATA
 
@@ -259,7 +252,7 @@ class JSOCClient(object):
             >>> from sunpy.net import jsoc
             >>> from sunpy.net import attrs as a
             >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
-            >>> response = client.search(a.jsoc.Time('2017-09-06T12:00:00', '2017-09-06T12:02:00'),
+            >>> response = client.search(a.Time('2017-09-06T12:00:00', '2017-09-06T12:02:00'),
             ...                          a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Wavelength(304*u.AA),
             ...                          a.jsoc.Segment('image'))  # doctest: +REMOTE_DATA
             >>> print(response)  # doctest: +REMOTE_DATA
@@ -285,7 +278,7 @@ class JSOCClient(object):
             >>> from sunpy.net import jsoc
             >>> from sunpy.net import attrs as a
             >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
-            >>> response = client.search(a.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
+            >>> response = client.search(a.Time('2014-01-01T00:00:00', '2014-01-01T00:10:00'),
             ...                          a.jsoc.Series('hmi.v_45s'),
             ...                          a.jsoc.Keys('T_REC, DATAMEAN, OBS_VR'))  # doctest: +REMOTE_DATA
             >>> print(response)  # doctest: +REMOTE_DATA
@@ -314,7 +307,7 @@ class JSOCClient(object):
             >>> from sunpy.net import jsoc
             >>> from sunpy.net import attrs as a
             >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
-            >>> response = client.search(a.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T00:01:00'),
+            >>> response = client.search(a.Time('2014-01-01T00:00:00', '2014-01-01T00:01:00'),
             ...                          a.jsoc.Series('aia.lev1_euv_12s'),
             ...                          a.jsoc.PrimeKey('WAVELNTH','171'))  # doctest: +REMOTE_DATA
             >>> print(response)  # doctest: +REMOTE_DATA
@@ -341,13 +334,6 @@ class JSOCClient(object):
         return_results.query_args = blocks
         return return_results
 
-    @deprecated('0.8', alternative='JSOCClient.search')
-    def query(self, *query, **kwargs):
-        """
-        See `~sunpy.net.jsoc.jsoc.JSOCClient.search`
-        """
-        return self.search(*query, **kwargs)
-
     def search_metadata(self, *query, **kwargs):
         """
         Get the metadata of all the files obtained in a search query.
@@ -381,7 +367,7 @@ class JSOCClient(object):
             >>> from sunpy.net import attrs as a
             >>> client = jsoc.JSOCClient()  # doctest: +REMOTE_DATA
             >>> metadata = client.search_metadata(
-            ...                         a.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T00:01:00'),
+            ...                         a.Time('2014-01-01T00:00:00', '2014-01-01T00:01:00'),
             ...                         a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Wavelength(304*u.AA))  # doctest: +REMOTE_DATA
             >>> print(metadata[['T_OBS', 'WAVELNTH']])  # doctest: +REMOTE_DATA
                                                                         T_OBS  WAVELNTH
@@ -447,54 +433,8 @@ class JSOCClient(object):
             return requests[0]
         return requests
 
-    @deprecated('0.9', alternative='drms.ExportRequest.status')
-    def check_request(self, requests):
-        """
-        Check the status of a request and print out a message about it.
-
-        Parameters
-        ----------
-        requests :  `~drms.ExportRequest` object or
-                   a list of  `~drms.ExportRequest` objects,
-                   returned by `~sunpy.net.jsoc.jsoc.JSOCClient.request_data`
-
-        Returns
-        -------
-        status : `int` or `list`
-            A status or list of status' that were returned by JSOC.
-
-        """
-        # Convert IDs to a list if not already
-        if not isiterable(requests) or isinstance(requests, drms.ExportRequest):
-            requests = [requests]
-
-        allstatus = []
-        for request in requests:
-            status = request.status
-
-            if status == request._status_code_ok:  # Data ready to download
-                print("Request {0} was exported at {1} and is ready to "
-                      "download.".format(request.id,
-                                         request._d['exptime']))
-            elif status in request._status_codes_pending:
-                print_message = "Request {0} was submitted {1} seconds ago, "\
-                                "it is not ready to download."
-                print(print_message.format(request.id,
-                                           request._d['wait']))
-            else:
-                print_message = "Request returned status: {0} with error: {1}"
-                json_status = request.status
-                json_error = request._d.get('error', '')
-                print(print_message.format(json_status, json_error))
-
-            allstatus.append(status)
-
-        if len(allstatus) == 1:
-            return allstatus[0]
-        return allstatus
-
-    def fetch(self, jsoc_response, path=None, overwrite=False, progress=True,
-              max_conn=5, downloader=None, sleep=10):
+    def fetch(self, jsoc_response, path=None, progress=True, overwrite=False,
+              downloader=None, wait=True, sleep=10):
         """
         Make the request for the data in a JSOC response and wait for it to be
         staged and then download the data.
@@ -507,17 +447,26 @@ class JSOCClient(object):
         path : `str`
             Path to save data to, defaults to SunPy download dir
 
-        overwrite : `bool`
-            Replace files with the same name if True
+        progress : `bool`, optional
+            If `True` show a progress bar showing how many of the total files
+            have been downloaded. If `False`, no progress bar will be shown.
 
-        progress : `bool`
-            Print progress info to terminal
+        overwrite : `bool` or `str`, optional
+            Determine how to handle downloading if a file already exists with the
+            same name. If `False` the file download will be skipped and the path
+            returned to the existing file, if `True` the file will be downloaded
+            and the existing file will be overwritten, if `'unique'` the filename
+            will be modified to be unique.
 
         max_conns : `int`
             Maximum number of download connections.
 
-        downloader: `~sunpy.net.download.Downloader` instance
-            A Custom downloader to use
+        downloader : `parfive.Downloader`, optional
+            The download manager to use.
+
+        wait : `bool`, optional
+           If `False` ``downloader.download()`` will not be called. Only has
+           any effect if `downloader` is not `None`.
 
         sleep : `int`
             The number of seconds to wait between calls to JSOC to check the status
@@ -529,36 +478,26 @@ class JSOCClient(object):
             A Results object
 
         """
-
         # Make staging request to JSOC
         responses = self.request_data(jsoc_response)
+
         # Make response iterable
         if not isiterable(responses):
             responses = [responses]
+
         # Add them to the response for good measure
         jsoc_response.requests = [r for r in responses]
         time.sleep(sleep/2.)
 
-        r = Results(lambda x: None, done=lambda maps: [v['path'] for v in maps.values()])
-
         for response in responses:
             response.wait(verbose=progress)
-            r = self.get_request(response, path=path, overwrite=overwrite,
-                                 progress=progress, results=r)
 
-        return r
-
-    @deprecated('0.8', alternative='JSOCClient.fetch')
-    def get(self, jsoc_response, path=None, overwrite=False, progress=True,
-            max_conn=5, downloader=None, sleep=10):
-        """
-        See `~sunpy.net.jsoc.jsoc.JSOCClient.fetch`
-        """
-        return self.fetch(jsoc_response, path=path, overwrite=overwrite, progress=progress,
-                          max_conn=max_conn, downloader=downloader, sleep=sleep)
+        return self.get_request(responses, path=path, overwrite=overwrite,
+                                progress=progress, downloader=downloader,
+                                wait=wait)
 
     def get_request(self, requests, path=None, overwrite=False, progress=True,
-                    max_conn=5, downloader=None, results=None):
+                    downloader=None, wait=True):
         """
         Query JSOC to see if the request(s) is ready for download.
 
@@ -573,20 +512,23 @@ class JSOCClient(object):
         path : `str`
             Path to save data to, defaults to SunPy download dir.
 
-        overwrite : `bool`
-            Replace files with the same name if True.
+        progress : `bool`, optional
+            If `True` show a progress bar showing how many of the total files
+            have been downloaded. If `False`, no progress bar will be shown.
 
-        progress : `bool`
-            Print progress info to terminal.
+        overwrite : `bool` or `str`, optional
+            Determine how to handle downloading if a file already exists with the
+            same name. If `False` the file download will be skipped and the path
+            returned to the existing file, if `True` the file will be downloaded
+            and the existing file will be overwritten, if `'unique'` the filename
+            will be modified to be unique.
 
-        max_conns : `int`
-            Maximum number of download connections.
+        downloader : `parfive.Downloader`, optional
+            The download manager to use.
 
-        downloader : `~sunpy.net.download.Downloader`
-            A Custom downloader to use
-
-        results: `~sunpy.net.download.Results`
-            A `~sunpy.net.download.Results` manager to use.
+        wait : `bool`, optional
+           If `False` ``downloader.download()`` will not be called. Only has
+           any effect if `downloader` is not `None`.
 
         Returns
         -------
@@ -597,12 +539,12 @@ class JSOCClient(object):
         c = drms.Client()
 
         # Convert Responses to a list if not already
-        if isinstance(requests, six.string_types) or not isiterable(requests):
+        if isinstance(requests, str) or not isiterable(requests):
             requests = [requests]
 
         # Ensure all the requests are drms ExportRequest objects
         for i, request in enumerate(requests):
-            if isinstance(request, six.string_types):
+            if isinstance(request, str):
                 r = c.export_from_id(request)
                 requests[i] = r
 
@@ -615,7 +557,7 @@ class JSOCClient(object):
         if path is None:
             default_dir = config.get("downloads", "download_dir")
             path = os.path.join(default_dir, '{file}')
-        elif isinstance(path, six.string_types) and '{file}' not in path:
+        elif isinstance(path, str) and '{file}' not in path:
             path = os.path.join(path, '{file}')
 
         paths = []
@@ -629,50 +571,30 @@ class JSOCClient(object):
                     fname = path
                 fname = fname.format(file=filename)
                 fname = os.path.expanduser(fname)
-                fname = partial(simple_path, fname)
                 paths.append(fname)
 
-        if downloader is None:
-            downloader = Downloader(max_conn=max_conn, max_total=max_conn)
-
-        # A Results object tracks the number of downloads requested and the
-        # number that have been completed.
-        if results is None:
-            results = Results(lambda _: downloader.stop(),
-                              done=lambda maps: [v['path'] for v in maps.values()])
+        dl_set = True
+        if not downloader:
+            dl_set = False
+            downloader = Downloader(progress=progress, overwrite=overwrite)
 
         urls = []
         for request in requests:
-
             if request.status == 0:
                 for index, data in request.data.iterrows():
-                    is_file = os.path.isfile(paths[index].args[0])
-                    if overwrite or not is_file:
-                        url_dir = request.request_url + '/'
-                        urls.append(urllib.parse.urljoin(url_dir, data['filename']))
-
-                    if not overwrite and is_file:
-                        print_message = "Skipping download of file {} as it " \
-                                        "has already been downloaded. " \
-                                        "If you want to redownload the data, "\
-                                        "please set overwrite to True"
-                        print(print_message.format(data['filename']))
-                        # Add the file on disk to the output
-                        results.map_.update({data['filename']:
-                                            {'path': paths[index].args[0]}})
+                    url_dir = request.request_url + '/'
+                    urls.append(urllib.parse.urljoin(url_dir, data['filename']))
         if urls:
             if progress:
                 print_message = "{0} URLs found for download. Full request totalling {1}MB"
                 print(print_message.format(len(urls), request._d['size']))
-            for i, url in enumerate(urls):
-                downloader.download(url, callback=results.require([url]),
-                                    errback=lambda x: print(x), path=paths[i])
+            for aurl, fname in zip(urls, paths):
+                downloader.enqueue_file(aurl, filename=fname)
 
-        else:
-            # Make Results think it has finished.
-            results.require([])
-            results.poke()
+        if dl_set and not wait:
+            return Results()
 
+        results = downloader.download()
         return results
 
     def _make_recordset(self, series, start_time='', end_time='', wavelength='',
@@ -741,12 +663,12 @@ class JSOCClient(object):
         if segment:
             if isinstance(segment, list):
                 segment = str(segment)[1:-1].replace(' ', '').replace("'", '')
-            segment = '{{{segment}}}'.format(segment=segment)
+            segment = f'{{{segment}}}'
 
         # Extract and format sample
         sample = kwargs.get('sample', '')
         if sample:
-            sample = '@{}s'.format(sample)
+            sample = f'@{sample}s'
 
         # Populate primekeys dict with Time and Wavelength values
         if start_time and end_time:
@@ -755,8 +677,8 @@ class JSOCClient(object):
             # either through PrimeKey() attribute or Time() attribute.
             if not any(x in PKEY_LIST_TIME for x in primekey):
                 timestr = '{start}-{end}{sample}'.format(
-                        start=start_time.strftime("%Y.%m.%d_%H:%M:%S_TAI"),
-                        end=end_time.strftime("%Y.%m.%d_%H:%M:%S_TAI"),
+                        start=start_time.tai.strftime("%Y.%m.%d_%H:%M:%S_TAI"),
+                        end=end_time.tai.strftime("%Y.%m.%d_%H:%M:%S_TAI"),
                         sample=sample)
             else:
                 error_message = "Time attribute has been passed both as a Time()"\
@@ -777,7 +699,7 @@ class JSOCClient(object):
                 raise ValueError(error_message)
 
             if match:
-                timestr = '{0}'.format(primekey.pop(list(match)[0], ''))
+                timestr = '{}'.format(primekey.pop(list(match)[0], ''))
             else:
                 timestr = ''
 
@@ -787,7 +709,7 @@ class JSOCClient(object):
                     wavelength = [int(np.ceil(wave.to(u.AA).value)) for wave in wavelength]
                     wavelength = str(wavelength)
                 else:
-                    wavelength = '{0}'.format(int(np.ceil(wavelength.to(u.AA).value)))
+                    wavelength = '{}'.format(int(np.ceil(wavelength.to(u.AA).value)))
 
             else:
                 # This is executed when wavelength has been passed both through PrimeKey()
@@ -799,7 +721,7 @@ class JSOCClient(object):
 
         else:
             # This is executed when wavelength has been passed through PrimeKey().
-            wavelength = '{0}'.format(primekey.pop('WAVELNTH', ''))
+            wavelength = '{}'.format(primekey.pop('WAVELNTH', ''))
 
         # Populate primekey dict with formatted Time and Wavlength.
         if timestr:
@@ -816,9 +738,9 @@ class JSOCClient(object):
             # The loop is iterating over the list of prime-keys existing for the given series.
             if len(primekey) > 0:
                 if pkeys_isTime[pkey]:
-                    pkstr += '[{0}]'.format(primekey.pop('TIME', ''))
+                    pkstr += '[{}]'.format(primekey.pop('TIME', ''))
                 else:
-                    pkstr += '[{0}]'.format(primekey.pop(pkey, ''))
+                    pkstr += '[{}]'.format(primekey.pop(pkey, ''))
             else:
                 break
                 # break because we can skip adding {} at the end of pkstr, if the primekey
@@ -853,7 +775,7 @@ class JSOCClient(object):
             error_message = "Series must be specified for a JSOC Query"
             raise ValueError(error_message)
 
-        if not isinstance(keywords, list) and not isinstance(keywords, six.string_types):
+        if not isinstance(keywords, list) and not isinstance(keywords, str):
             error_message = "Keywords can only be passed as a list or "\
                             "comma-separated strings."
             raise TypeError(error_message)
@@ -885,12 +807,12 @@ class JSOCClient(object):
         segs_passed = iargs.get('segment', None)
         if segs_passed is not None:
 
-            if not isinstance(segs_passed, list) and not isinstance(segs_passed, six.string_types):
+            if not isinstance(segs_passed, list) and not isinstance(segs_passed, str):
                 error_message = "Segments can only be passed as a comma-separated"\
                                 " string or a list of strings."
                 raise TypeError(error_message)
 
-            elif isinstance(segs_passed, six.string_types):
+            elif isinstance(segs_passed, str):
                 segs_passed = segs_passed.replace(' ', '').split(',')
 
             if not set(segs_passed) <= set(segs):
@@ -903,9 +825,6 @@ class JSOCClient(object):
         # If Time has been passed as a PrimeKey, convert the Time object into TAI time scale,
         # and then, convert it to datetime object.
 
-        iargs['start_time'] = iargs['start_time'].tai.datetime
-        iargs['end_time'] = iargs['end_time'].tai.datetime
-
         ds = self._make_recordset(**iargs)
 
         # Convert the list of keywords into comma-separated string.
