@@ -5,6 +5,8 @@ import astropy.units as u
 
 import sunpy.net.jsoc as jsoc
 import sunpy.net.jsoc.attrs as attrs
+import sunpy.net.vso.attrs as vso_attrs
+
 from sunpy.net.attr import AttrOr, AttrAnd
 
 
@@ -19,7 +21,7 @@ def test_and(attr1, attr2):
 
 def test_basicquery():
     a1 = attrs.Series('foo')
-    t1 = attrs.Time('2012/01/01', '2013/1/2')
+    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
     ans1 = jsoc.jsoc.and_(a1, t1)
     assert isinstance(ans1, AttrAnd)
     assert len(ans1.attrs) == 2
@@ -28,7 +30,7 @@ def test_basicquery():
 def test_mediumquery():
     a1 = attrs.Series('foo1')
     a2 = attrs.Series('foo2')
-    t1 = attrs.Time('2012/01/01', '2013/1/2')
+    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
     ans1 = jsoc.jsoc.and_(a1 | a2, t1)
     assert isinstance(ans1, AttrOr)
     assert isinstance(ans1.attrs[0], AttrAnd)
@@ -38,8 +40,8 @@ def test_mediumquery():
 def test_complexquery():
     a1 = attrs.Series('foo1')
     a2 = attrs.Series('foo2')
-    t1 = attrs.Time('2012/01/01', '2013/1/2')
-    t2 = attrs.Time('2012/01/01', '2013/1/3')
+    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
+    t2 = vso_attrs.Time('2012/01/01', '2013/1/3')
     ans1 = jsoc.jsoc.and_(a1 | a2, t1 | t2)
     assert isinstance(ans1.attrs[0], AttrOr)
     assert isinstance(ans1.attrs[0].attrs[0], AttrAnd)
