@@ -1,61 +1,45 @@
 # -*- coding: utf-8 -*-
-# Author: Florian Mayer <florian.mayer@bitsrc.org>
-#
-# This module was developed with funding provided by
-# the ESA Summer of Code (2011).
-#
-# pylint: disable=W0401,C0103,R0904,W0141
-from __future__ import absolute_import, division, print_function
-
 """
 This module provides a wrapper around the VSO API.
 """
 
-import re
 import os
+import re
 import sys
-import copy
-import logging
-import requests
-import warnings
 import socket
+import warnings
 import itertools
-
-from datetime import datetime, timedelta
 from functools import partial
 from collections import defaultdict
-from suds import client, TypeNotFound
+from urllib.error import URLError, HTTPError
+from urllib.request import urlopen
+
+import zeep
+from zeep.helpers import serialize_object
 
 import astropy.units as u
 from astropy.table import QTable as Table
+from parfive import Downloader, Results
 
 from sunpy import config
-from sunpy.net import download
-from sunpy.net.proxyfix import WellBehavedHttpTransport
-from sunpy.util.net import get_filename, slugify
-from sunpy.net.attr import and_, Attr
+from sunpy.time import TimeRange, parse_time
 from sunpy.net.vso import attrs
-from sunpy.net.vso.attrs import walker, TIMEFORMAT
-from sunpy.util import replacement_filename
-from sunpy.time import parse_time
-
-from sunpy.util import deprecated
-from sunpy.extern import six
-from sunpy.extern.six import iteritems, text_type
-from sunpy.extern.six.moves import input
+from sunpy.net.attr import and_
+from sunpy.util.net import slugify, get_content_disposition
+from sunpy.net.vso.attrs import TIMEFORMAT, walker
+from sunpy.net.base_client import BaseClient
+from sunpy.util.decorators import deprecated
+from sunpy.util.exceptions import SunpyUserWarning
 
 TIME_FORMAT = config.get("general", "time_format")
 
 DEFAULT_URL_PORT = [{'url': 'http://docs.virtualsolar.org/WSDL/VSOi_rpc_literal.wsdl',
-                     'port': 'nsoVSOi', 'transport': WellBehavedHttpTransport}]
+                     'port': 'nsoVSOi'},
+                    {'url': 'https://sdac.virtualsolar.org/API/VSOi_rpc_literal.wsdl',
+                     'port': 'sdacVSOi'}]
 
 RANGE = re.compile(r'(\d+)(\s*-\s*(\d+))?(\s*([a-zA-Z]+))?')
 
-# Override the logger that dumps the whole Schema
-# to stderr so it doesn't do that.
-suds_log = logging.getLogger('suds.umx.typed')
-suds_log.setLevel(50)
-
 
 # TODO: Name
 class NoData(Exception):
@@ -92,8 +76,7 @@ def iter_records(response):
     for prov_item in response.provideritem:
         if not hasattr(prov_item, 'record') or not prov_item.record:
             continue
-        for record_item in prov_item.record.recorditem:
-            yield record_item
+        yield from prov_item.record.recorditem
 
 
 def iter_errors(response):
@@ -104,30 +87,35 @@ def iter_errors(response):
 
 def check_connection(url):
     try:
-        return requests.get(url).status_code == 200
-    except (socket.error, socket.timeout) as e:
-        warnings.warn(
-            "Connection failed with error {}. \n Retrying with different url and port.".format(e))
+        return urlopen(url).getcode() == 200
+    except (socket.error, socket.timeout, HTTPError, URLError) as e:
+        warnings.warn(f"Connection failed with error {e}. Retrying with different url and port.",
+                      SunpyUserWarning)
+        return None
 
 
 def get_online_vso_url(api, url, port):
-    if api is None and (url is None or port is None):
-        for mirror in DEFAULT_URL_PORT:
-            if check_connection(mirror['url']):
-                api = client.Client(
-                    mirror['url'], transport=mirror['transport']())
-                api.set_options(port=mirror['port'])
-                return api
+    if isinstance(api, zeep.client.Client):
+        return api
+
+    if url and check_connection(url):
+        api = zeep.Client(url, port)
+        return api
+
+    for mirror in DEFAULT_URL_PORT:
+        if check_connection(mirror['url']):
+            api = zeep.Client(mirror['url'], port_name=mirror['port'])
+            api.set_ns_prefix('VSO', 'http://virtualsolar.org/VSO/VSOi')
+            return api
 
 
-# TODO: Python 3 this should subclass from UserList
 class QueryResponse(list):
     """
     A container for VSO Records returned from VSO Searches.
     """
 
     def __init__(self, lst, queryresult=None, table=None):
-        super(QueryResponse, self).__init__(lst)
+        super().__init__(lst)
         self.queryresult = queryresult
         self.errors = []
         self.table = None
@@ -140,13 +128,6 @@ class QueryResponse(list):
             attrs.filter_results(query, self), self.queryresult
         )
 
-    @deprecated('0.8', alternative='QueryResponse.search')
-    def query(self, *query):
-        """
-        See `~sunpy.net.vso.vso.QueryResponse.search`
-        """
-        return self.search(*query)
-
     @classmethod
     def create(cls, queryresult):
         return cls(iter_records(queryresult), queryresult)
@@ -159,14 +140,8 @@ class QueryResponse(list):
 
     def time_range(self):
         """ Return total time-range all records span across. """
-        return (
-            datetime.strptime(
-                min(record.time.start for record in self
-                    if record.time.start is not None), TIMEFORMAT),
-            datetime.strptime(
-                max(record.time.end for record in self
-                    if record.time.end is not None), TIMEFORMAT)
-        )
+        return TimeRange(min(record.time.start for record in self if record.time.start is not None),
+                         max(record.time.end for record in self if record.time.end is not None))
 
     def build_table(self):
         """
@@ -186,7 +161,7 @@ class QueryResponse(list):
             if time is None:
                 return ['None']
             if record.time.start is not None:
-                return [datetime.strftime(parse_time(time), TIME_FORMAT)]
+                return [parse_time(time).strftime(TIME_FORMAT)]
             else:
                 return ['N/A']
 
@@ -199,9 +174,13 @@ class QueryResponse(list):
                                         if record.extent.type is not None else ['N/A'])
             # If we have a start and end Wavelength, make a quantity
             if hasattr(record, 'wave') and record.wave.wavemin and record.wave.wavemax:
+                unit = record.wave.waveunit
+                # Convert this so astropy units parses it correctly
+                if unit == "kev":
+                    unit = "keV"
                 record_items['Wavelength'].append(u.Quantity([float(record.wave.wavemin),
                                                               float(record.wave.wavemax)],
-                                                             unit=record.wave.waveunit))
+                                                             unit=unit))
             # If not save None
             else:
                 record_items['Wavelength'].append(None)
@@ -275,38 +254,25 @@ class UnknownStatus(Exception):
     pass
 
 
-class VSOClient(object):
+class VSOClient(BaseClient):
 
     """ Main VSO Client. """
     method_order = [
-        'URL-TAR_GZ', 'URL-ZIP', 'URL-TAR', 'URL-FILE', 'URL-packaged'
+        'URL-FILE_Rice', 'URL-FILE', 'URL-packaged', 'URL-TAR_GZ', 'URL-ZIP', 'URL-TAR',
     ]
 
     def __init__(self, url=None, port=None, api=None):
         api = get_online_vso_url(api, url, port)
+        if api is None:
+            raise ConnectionError("Cannot find an online VSO mirror.")
         self.api = api
 
     def make(self, atype, **kwargs):
-        """ Create new SOAP object with attributes specified in kwargs.
-        To assign subattributes, use foo__bar=1 to assign
-        ['foo']['bar'] = 1. """
-        obj = self.api.factory.create(atype)
-        for k, v in iteritems(kwargs):
-            split = k.split('__')
-            tip = split[-1]
-            rest = split[:-1]
-
-            item = obj
-            for elem in rest:
-                item = item[elem]
-
-            if isinstance(v, dict):
-                # Do not throw away type information for dicts.
-                for k, v in iteritems(v):
-                    item[tip][k] = v
-            else:
-                item[tip] = v
-        return obj
+        """
+        Create a new SOAP object.
+        """
+        obj = self.api.get_type(f"VSO:{atype}")
+        return obj(**kwargs)
 
     def search(self, *query):
         """ Query data from the VSO with the new API. Takes a variable number
@@ -340,33 +306,25 @@ class VSOClient(object):
         -------
         out : :py:class:`QueryResult` (enhanced list)
             Matched items. Return value is of same type as the one of
-            :py:meth:`VSOClient.query`.
+            :py:meth:`VSOClient.search`.
         """
         query = and_(*query)
-
+        QueryRequest = self.api.get_type('VSO:QueryRequest')
+        VSOQueryResponse = self.api.get_type('VSO:QueryResponse')
         responses = []
         for block in walker.create(query, self.api):
             try:
                 responses.append(
-                    self.api.service.Query(
-                        self.make('QueryRequest', block=block)
-                    )
+                    VSOQueryResponse(self.api.service.Query(
+                        QueryRequest(block=block)
+                    ))
                 )
-            except TypeNotFound:
-                pass
             except Exception as ex:
                 response = QueryResponse.create(self.merge(responses))
                 response.add_error(ex)
 
         return QueryResponse.create(self.merge(responses))
 
-    @deprecated('0.8', alternative='VSOClient.search')
-    def query(self, *query):
-        """
-        See `~sunpy.net.vso.VSOClient.search`
-        """
-        return self.search(*query)
-
     def merge(self, queryresponses):
         """ Merge responses into one. """
         if len(queryresponses) == 1:
@@ -384,10 +342,10 @@ class VSOClient(object):
                     continue
                 if provideritem.provider not in providers:
                     providers[provider] = provideritem
-                    fileids |= set(
+                    fileids |= {
                         record_item.fileid
                         for record_item in provideritem.record.recorditem
-                    )
+                    }
                 else:
                     for record_item in provideritem.record.recorditem:
                         if record_item.fileid not in fileids:
@@ -401,13 +359,18 @@ class VSOClient(object):
                          provideritem=list(providers.values()))
 
     @staticmethod
-    def mk_filename(pattern, response, sock, url, overwrite=False):
-        name = get_filename(sock, url)
+    def mk_filename(pattern, queryresponse, resp, url):
+        name = None
+        url_filename = url.split('/')[-1]
+        if resp:
+            name = resp.headers.get("Content-Disposition", url_filename)
+            if name:
+                name = get_content_disposition(name)
         if not name:
-            if not isinstance(response.fileid, text_type):
-                name = six.u(response.fileid, "ascii", "ignore")
+            if isinstance(queryresponse.fileid, bytes):
+                name = queryresponse.fileid.decode("ascii", "ignore")
             else:
-                name = response.fileid
+                name = queryresponse.fileid
 
         fs_encoding = sys.getfilesystemencoding()
         if fs_encoding is None:
@@ -415,23 +378,14 @@ class VSOClient(object):
 
         name = slugify(name)
 
-        if six.PY2:
-            name = name.encode(fs_encoding, "ignore")
-
         if not name:
             name = "file"
 
-        fname = pattern.format(file=name, **dict(response))
+        fname = pattern.format(file=name, **serialize_object(queryresponse))
 
-        if not overwrite and os.path.exists(fname):
-            fname = replacement_filename(fname)
-
-        dir_ = os.path.abspath(os.path.dirname(fname))
-        if not os.path.exists(dir_):
-            os.makedirs(dir_)
         return fname
 
-    # pylint: disable=R0914
+    @deprecated("1.0", alternative="sunpy.net.Fido")
     def query_legacy(self, tstart=None, tend=None, **kwargs):
         """
         Query data from the VSO mocking the IDL API as close as possible.
@@ -474,7 +428,6 @@ class VSOClient(object):
             detector ID (C3, EUVI, COR2, etc.)
         layout : str
             layout of the data (image, spectrum, time_series, etc.)
-
         level : str
             level of the data product (numeric range, see below)
         pixels : str
@@ -504,17 +457,18 @@ class VSOClient(object):
 
         >>> from datetime import datetime
         >>> from sunpy.net import vso
-        >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
+        >>> client = vso.VSOClient()  # doctest: +SKIP
         >>> qr = client.query_legacy(datetime(2010, 1, 1),
-        ...                          datetime(2010, 1, 1, 1), instrument='eit')  # doctest: +REMOTE_DATA
+        ...                          datetime(2010, 1, 1, 1),
+        ...                          instrument='eit')  # doctest: +SKIP
 
         Returns
         -------
         out : :py:class:`QueryResult` (enhanced list)
             Matched items. Return value is of same type as the one of
-            :py:class:`VSOClient.query`.
+            :py:class:`VSOClient.search`.
         """
-        sdk = lambda key: lambda value: {key: value}
+        def sdk(key): return partial(lambda key, value: {key: value}, key)
         ALIASES = {
             'wave_min': sdk('wave_wavemin'),
             'wave_max': sdk('wave_wavemax'),
@@ -542,45 +496,46 @@ class VSOClient(object):
         if tend is not None:
             kwargs.update({'time_end': tend})
 
-        queryreq = self.api.factory.create('QueryRequest')
-        for key, value in iteritems(kwargs):
-            for k, v in iteritems(ALIASES.get(key, sdk(key))(value)):
+        QueryRequest = self.api.get_type('VSO:QueryRequest')
+        VSOQueryResponse = self.api.get_type('VSO:QueryResponse')
+        block = self.api.get_type('VSO:QueryRequestBlock')()
+
+        for key, value in kwargs.items():
+            for k, v in ALIASES.get(key, sdk(key))(value).items():
                 if k.startswith('time'):
                     v = parse_time(v).strftime(TIMEFORMAT)
                 attr = k.split('_')
                 lst = attr[-1]
                 rest = attr[:-1]
 
-                # pylint: disable=E1103
-                item = queryreq.block
                 for elem in rest:
                     try:
-                        item = item[elem]
+                        if block[elem] is None:
+                            block[elem] = {}
+                        block = block[elem]
                     except KeyError:
                         raise ValueError(
-                            "Unexpected argument {key!s}.".format(key=key))
-                if lst not in item:
+                            f"Unexpected argument {key!s}.")
+                if lst in block and block[lst]:
                     raise ValueError(
-                        "Unexpected argument {key!s}.".format(key=key))
-                if item[lst]:
-                    raise ValueError(
-                        "Got multiple values for {k!s}.".format(k=k))
-                item[lst] = v
-        try:
-            return QueryResponse.create(self.api.service.Query(queryreq))
-        except TypeNotFound:
-            return QueryResponse([])
+                        f"Got multiple values for {k!s}.")
+                block[lst] = v
 
+        return QueryResponse.create(VSOQueryResponse(
+            self.api.service.Query(QueryRequest(block=block))))
+
+    @deprecated("1.0")
     def latest(self):
         """ Return newest record (limited to last week). """
+        from datetime import datetime, timedelta
         return self.query_legacy(
             datetime.utcnow() - timedelta(7),
             datetime.utcnow(),
             time_near=datetime.utcnow()
         )
 
-    def fetch(self, query_response, path=None, methods=('URL-FILE_Rice', 'URL-FILE'),
-              downloader=None, site=None):
+    def fetch(self, query_response, path=None, methods=None, site=None,
+              progress=True, overwrite=False, downloader=None, wait=True):
         """
         Download data specified in the query_response.
 
@@ -601,13 +556,10 @@ class VSOClient(object):
             Methods are a concatenation of one PREFIX followed by any number of
             SUFFIXES i.e. `PREFIX-SUFFIX_SUFFIX2_SUFFIX3`.
             The full list of
-            `PREFIXES <http://sdac.virtualsolar.org/cgi/show_details?keyword=METHOD_PREFIX>`_
-            and `SUFFIXES <http://sdac.virtualsolar.org/cgi/show_details?keyword=METHOD_SUFFIX>`_
+            `PREFIXES <https://sdac.virtualsolar.org/cgi/show_details?keyword=METHOD_PREFIX>`_
+            and `SUFFIXES <https://sdac.virtualsolar.org/cgi/show_details?keyword=METHOD_SUFFIX>`_
             are listed on the VSO site.
 
-        downloader : sunpy.net.downloader.Downloader
-            Downloader used to download the data.
-
         site : str
             There are a number of caching mirrors for SDO and other
             instruments, some available ones are listed below.
@@ -624,59 +576,67 @@ class VSOClient(object):
             NMSU            New Mexico State University (US)
             =============== ========================================================
 
+        progress : `bool`, optional
+            If `True` show a progress bar showing how many of the total files
+            have been downloaded. If `False`, no progress bars will be shown at all.
+
+        overwrite : `bool` or `str`, optional
+            Determine how to handle downloading if a file already exists with the
+            same name. If `False` the file download will be skipped and the path
+            returned to the existing file, if `True` the file will be downloaded
+            and the existing file will be overwritten, if `'unique'` the filename
+            will be modified to be unique.
+
+        downloader : `parfive.Downloader`, optional
+            The download manager to use.
+
+        wait : `bool`, optional
+           If `False` ``downloader.download()`` will not be called. Only has
+           any effect if `downloader` is not `None`.
+
         Returns
         -------
-        out : :py:class:`Results`
-            Object that supplies a list of filenames with meta attributes
-            containing the respective QueryResponse.
+        out : `parfive.Results`
+            Object that supplies a list of filenames and any errors.
 
         Examples
         --------
-        >>> res = fetch(qr).wait() # doctest:+SKIP
+        >>> files = fetch(qr) # doctest:+SKIP
         """
-        if downloader is None:
-            downloader = download.Downloader()
-            downloader.init()
-            res = download.Results(
-                lambda _: downloader.stop(), 1,
-                lambda mp: self.link(query_response, mp)
-            )
-        else:
-            res = download.Results(
-                lambda _: None, 1, lambda mp: self.link(query_response, mp)
-            )
         if path is None:
             path = os.path.join(config.get('downloads', 'download_dir'),
                                 '{file}')
-        elif isinstance(path, six.string_types) and '{file}' not in path:
+        elif isinstance(path, str) and '{file}' not in path:
             path = os.path.join(path, '{file}')
         path = os.path.expanduser(path)
 
+        dl_set = True
+        if not downloader:
+            dl_set = False
+            downloader = Downloader(progress=progress)
+
         fileids = VSOClient.by_fileid(query_response)
         if not fileids:
-            res.poke()
-            return res
+            return downloader.download() if wait else Results()
         # Adding the site parameter to the info
         info = {}
         if site is not None:
             info['site'] = site
 
-        self.download_all(
-            self.api.service.GetData(
-                self.make_getdatarequest(query_response, methods, info)),
-            methods, downloader, path,
-            fileids, res
-        )
-        res.poke()
-        return res
+        VSOGetDataResponse = self.api.get_type("VSO:VSOGetDataResponse")
 
-    @deprecated('0.8', alternative='VSOClient.fetch')
-    def get(self, query_response, path=None, methods=('URL-FILE_Rice', 'URL-FILE'),
-            downloader=None, site=None):
-        """
-        See `~sunpy.net.vso.VSOClient.fetch`
-        """
-        return self.fetch(query_response, path=path, methods=methods, downloader=downloader, site=site)
+        data_request = self.make_getdatarequest(query_response, methods, info)
+        data_response = VSOGetDataResponse(self.api.service.GetData(data_request))
+
+        err_results = self.download_all(data_response, methods, downloader, path, fileids)
+
+        if dl_set and not wait:
+            return err_results
+
+        results = downloader.download()
+        results += err_results
+        results._errors += err_results.errors
+        return results
 
     @staticmethod
     def link(query_response, maps):
@@ -702,8 +662,8 @@ class VSOClient(object):
             methods = self.method_order + ['URL']
 
         return self.create_getdatarequest(
-            dict((k, [x.fileid for x in v])
-                 for k, v in iteritems(self.by_provider(response))),
+            {k: [x.fileid for x in v]
+                 for k, v in self.by_provider(response).items()},
             methods, info
         )
 
@@ -713,15 +673,17 @@ class VSOClient(object):
         if info is None:
             info = {}
 
+        if 'email' not in info:
+            info['email'] = 'sunpy'
+
         # For the JSOC provider we need to make a DataRequestItem for each
         # series, not just one for the whole provider.
 
         # Remove JSOC provider items from the map
         jsoc = maps.pop('JSOC', [])
-
         # Make DRIs for everything that's not JSOC one per provider
-        dris = [self.make('DataRequestItem', provider=k, fileiditem__fileid=[v])
-                for k, v in iteritems(maps)]
+        dris = [self.make('DataRequestItem', provider=k, fileiditem={'fileid': v})
+                for k, v in maps.items()]
 
         def series_func(x):
             """ Extract the series from the fileid. """
@@ -730,35 +692,36 @@ class VSOClient(object):
         # Sort the JSOC fileids by series
         # This is a precursor to groupby as recommended by the groupby docs
         series_sorted = sorted(jsoc, key=series_func)
-
         # Iterate over the series and make a DRI for each.
         # groupby creates an iterator based on a key function, in this case
         # based on the series (the part before the first ':')
         for series, fileids in itertools.groupby(series_sorted, key=series_func):
             dris.append(self.make('DataRequestItem',
                                   provider='JSOC',
-                                  fileiditem__fileid=[list(fileids)]))
+                                  fileiditem={'fileid': list(fileids)}))
 
-        return self.make(
-            'VSOGetDataRequest',
-            request__method__methodtype=methods,
-            request__info=info,
-            request__datacontainer__datarequestitem=dris
-        )
+        request = {'method': {'methodtype': methods},
+                   'info': info,
+                   'datacontainer': {'datarequestitem': dris}
+                   }
+
+        return self.make('VSOGetDataRequest', request=request)
 
     # pylint: disable=R0913,R0912
-    def download_all(self, response, methods, dw, path, qr, res, info=None):
+    def download_all(self, response, methods, downloader, path, qr, info=None):
+        results = Results()
         GET_VERSION = [
             ('0.8', (5, 8)),
             ('0.7', (1, 4)),
             ('0.6', (0, 3)),
         ]
+
         for dresponse in response.getdataresponseitem:
             for version, (from_, to) in GET_VERSION:
                 if getattr(dresponse, version, '0.6') >= version:
                     break
             else:
-                res.add_error(UnknownVersion(dresponse))
+                results.add_error('', UnknownVersion(dresponse))
                 continue
 
             # If from_ and to are uninitialized, the else block of the loop
@@ -766,27 +729,23 @@ class VSOClient(object):
             # pylint: disable=W0631
             code = (
                 dresponse.status[from_:to]
-                if hasattr(dresponse, 'status') else '200'
+                if getattr(dresponse, 'status', None) else '200'
             )
             if code == '200':
                 for dataitem in dresponse.getdataitem.dataitem:
+
                     try:
                         self.download(
                             dresponse.method.methodtype[0],
                             dataitem.url,
-                            dw,
-                            res.require(
-                                list(map(str, dataitem.fileiditem.fileid))),
-                            res.add_error,
+                            downloader,
                             path,
                             qr[dataitem.fileiditem.fileid[0]]
                         )
                     except NoData:
-                        res.add_error(DownloadFailed(dresponse))
+                        results.add_error('', DownloadFailed(dresponse))
                         continue
-                    except Exception:
-                        # FIXME: Is this a good idea?
-                        res.add_error(DownloadFailed(dresponse))
+
             elif code == '300' or code == '412' or code == '405':
                 if code == '300':
                     try:
@@ -794,7 +753,7 @@ class VSOClient(object):
                             dresponse.method.methodtype, dresponse
                         )
                     except NoData:
-                        res.add_error(MultipleChoices(dresponse))
+                        results.add_error('', MultipleChoices(dresponse))
                         continue
                 elif code == '412':
                     try:
@@ -802,13 +761,13 @@ class VSOClient(object):
                             info, dresponse.info
                         )
                     except NoData:
-                        res.add_error(MissingInformation(dresponse))
+                        results.add_error('', MissingInformation(dresponse))
                         continue
                 elif code == '405':
                     try:
                         methods = self.unknown_method(dresponse)
                     except NoData:
-                        res.add_error(UnknownMethod(dresponse))
+                        results.add_error('', UnknownMethod(dresponse))
                         continue
 
                 files = []
@@ -820,18 +779,19 @@ class VSOClient(object):
                 )
 
                 self.download_all(
-                    self.api.service.GetData(request), methods, dw, path,
-                    qr, res, info
+                    self.api.service.GetData(request), methods, downloader, path,
+                    qr, info
                 )
             else:
-                res.add_error(UnknownStatus(dresponse))
+                results.add_error(UnknownStatus(dresponse))
 
-    def download(self, method, url, dw, callback, errback, *args):
-        """ Override to costumize download action. """
+        return results
+
+    def download(self, method, url, downloader, *args):
+        """ Enqueue a file to be downloaded, extra args are passed to ``mk_filename``"""
         if method.startswith('URL'):
-            return dw.download(url, partial(self.mk_filename, *args),
-                               callback, errback
-                               )
+            return downloader.enqueue_file(url, filename=partial(self.mk_filename, *args))
+
         raise NoData
 
     @staticmethod
@@ -853,9 +813,9 @@ class VSOClient(object):
         corresponding to records in the response.
         """
 
-        return dict(
-            (record.fileid, record) for record in response
-        )
+        return {
+            record.fileid: record for record in response
+        }
 
     # pylint: disable=W0613
     def multiple_choices(self, choices, response):
@@ -878,115 +838,3 @@ class VSOClient(object):
     @classmethod
     def _can_handle_query(cls, *query):
         return all([x.__class__.__name__ in attrs.__all__ for x in query])
-
-
-@deprecated("0.8.0", alternative="Please use VSOClient")
-class InteractiveVSOClient(VSOClient):
-
-    """ Client for use in the REPL. Prompts user for data if required. """
-
-    def multiple_choices(self, choices, response):
-        """
-        not documented yet
-
-        Parameters
-        ----------
-
-            choices : not documented yet
-
-            response : not documented yet
-
-        """
-        while True:
-            for n, elem in enumerate(choices):
-                print("({num:d}) {choice!s}".format(num=n + 1, choice=elem))
-            try:
-                choice = input("Method number: ")
-            except KeyboardInterrupt:
-                raise NoData
-            if not choice:
-                raise NoData
-            try:
-                choice = int(choice) - 1
-            except ValueError:
-                continue
-            if choice == -1:
-                raise NoData
-            elif choice >= 0:
-                try:
-                    return [choices[choice]]
-                except IndexError:
-                    continue
-
-    def missing_information(self, info, field):
-        """
-        not documented yet
-
-        Parameters
-        ----------
-        info : not documented yet
-                not documented yet
-        field : not documented yet
-            not documented yet
-
-        Returns
-        -------
-        choice : not documented yet
-
-        .. todo::
-            improve documentation. what does this function do?
-
-        """
-        choice = input(field + ': ')
-        if not choice:
-            raise NoData
-        return choice
-
-    def search(self, *args, **kwargs):
-        """ When passed an Attr object, perform new-style query;
-        otherwise, perform legacy query.
-        """
-        if isinstance(args[0], Attr):
-            return self.query(*args)
-        else:
-            return self.query_legacy(*args, **kwargs)
-
-    def get(self, query_response, path=None, methods=('URL-FILE',), downloader=None):
-        """The path expands ``~`` to refer to the user's home directory.
-        If the given path is an already existing directory, ``{file}`` is
-        appended to this path. After that, all received parameters (including
-        the updated path) are passed to :meth:`VSOClient.get`.
-
-        """
-        if path is not None:
-            path = os.path.abspath(os.path.expanduser(path))
-            if os.path.exists(path) and os.path.isdir(path):
-                path = os.path.join(path, '{file}')
-        return VSOClient.fetch(self, query_response, path, methods, downloader)
-
-
-g_client = None
-
-
-@deprecated("0.8.0", alternative="Please use the VSO Clients directly")
-def search(*args, **kwargs):
-    # pylint: disable=W0603
-    global g_client
-    if g_client is None:
-        g_client = InteractiveVSOClient()
-    return g_client.search(*args, **kwargs)
-
-
-search.__doc__ = InteractiveVSOClient.search.__doc__
-
-
-@deprecated("0.8.0", alternative="Please use the VSO Clients directly")
-def get(query_response, path=None, methods=('URL-FILE',), downloader=None):
-    # pylint: disable=W0603
-    global g_client
-    if g_client is None:
-        g_client = InteractiveVSOClient()
-    return g_client.get(query_response, path, methods, downloader)
-
-
-get.__doc__ = VSOClient.search.__doc__
