@@ -1,18 +1,11 @@
-# -*- coding: utf-8 -*-
 """
-Created on Sat Jun  7 19:36:08 2014
-
-@author: Stuart Mumford
-
-This file is designed to be imported and ran only via setup.py, hence it's
+This file is designed to be imported and ran only via "setup.py", hence it's
 dependency on astropy_helpers which will be available in that context.
 """
-from __future__ import absolute_import, division, print_function
-
+import os
 import copy
 
 from astropy_helpers.commands.test import AstropyTest
-from astropy_helpers.compat import _fix_user_options
 
 
 class SunPyTest(AstropyTest):
@@ -28,21 +21,44 @@ class SunPyTest(AstropyTest):
                       'Also run tests that do require a internet connection.'),
                      ('online-only', None,
                       'Only run test that do require a internet connection.'),
+                     ('cov-report=', None,
+                      'How to display the coverage report, should be either "html" or "term"'),
                      ('figure', None,
                       'Run the figure tests.'),
                      # Run only tests that check figure generation
                      ('figure-only', None,
                       'Only run tests that compare figures against stored hashes.')]
 
-    user_options = _fix_user_options(user_options)
     package_name = ''
 
     def initialize_options(self):
-        super(SunPyTest, self).initialize_options()
+        super().initialize_options()
         self.online = False
         self.online_only = False
         self.figure = False
         self.figure_only = False
+        self.cov_report = True
+
+    def _generate_coverage_commands(self):
+        cmd_pre = ''  # Commands to run before the test function
+
+        # patch the .coverage file so the paths are correct to the directory
+        # setup.py was run in rather than the temporary directory.
+        cwd = os.path.abspath(".")
+        cmd_post = ('from sunpy.tests.helpers import _patch_coverage; '
+                    'import os; '
+                    'test_dir = os.path.abspath("."); '
+                    f'_patch_coverage(test_dir, "{cwd}"); ')
+
+        # Make html report the default and make pytest-cov save it to the
+        # source directory not the temporary directory.
+        if self.cov_report and (isinstance(self.cov_report, bool) or "html" in self.cov_report):
+            html_cov = os.path.join(os.path.abspath("."), "htmlcov")
+            self.cov_report = f'html:{html_cov}'
+        else:
+            self.cov_report = self.cov_report
+
+        return cmd_pre, cmd_post
 
     def generate_testing_command(self):
         """
@@ -62,6 +78,8 @@ class SunPyTest(AstropyTest):
                'package={1.package!r}, '
                'test_path={1.test_path!r}, '
                'args={1.args!r}, '
+               'coverage={1.coverage!r}, '
+               'cov_report={1.cov_report!r}, '
                'plugins={1.plugins!r}, '
                'verbose={1.verbose_results!r}, '
                'pastebin={1.pastebin!r}, '
@@ -69,6 +87,7 @@ class SunPyTest(AstropyTest):
                'online_only={1.online_only!r}, '
                'figure={1.figure!r}, '
                'figure_only={1.figure_only!r}, '
+               'figure_dir="{figure_dir}", '
                'pep8={1.pep8!r}, '
                'pdb={1.pdb!r}, '
                'open_files={1.open_files!r}, '
@@ -80,5 +99,6 @@ class SunPyTest(AstropyTest):
                'sys.exit(result)')
         return cmd.format('pass',
                           self,
+                          figure_dir=os.path.join(os.path.abspath('.'), "figure_test_images"),
                           cmd_pre=cmd_pre,
                           cmd_post=cmd_post)
