@@ -1,47 +1,50 @@
-from __future__ import absolute_import, division, print_function
-
+"""
+This module provies a object that can handle a time range.
+"""
 from datetime import timedelta
-from datetime import datetime
 
 import astropy.units as u
+from astropy.time import Time, TimeDelta
 
-from sunpy.time import parse_time
 from sunpy import config
-from sunpy.extern.six.moves import range
+from sunpy.time import is_time_equal, parse_time
+from sunpy.time.time import _variables_for_parse_time_docstring
+from sunpy.util.decorators import add_common_docstring
 
 TIME_FORMAT = config.get('general', 'time_format')
 
 __all__ = ['TimeRange']
 
 
-class TimeRange(object):
+@add_common_docstring(**_variables_for_parse_time_docstring())
+class TimeRange:
     """
-    An object to handle time ranges.
+    A class to create and handle time ranges.
 
     .. note::
 
-       Regardless of how a TimeRange is constructed it will always provide a
-       positive time range where the start time is before the end time.
+       Regardless of how a `sunpy.time.TimeRange` is constructed it will always
+       provide a positive time range where the start time is before the end time.
 
     Parameters
     ----------
-    a : str, number, `datetime.datetime`
-        A time (usually the start time) specified as a parse_time-compatible
+    a : {parse_time_types}
+        A time (the start time) specified as a parse_time-compatible
         time string, number, or a datetime object.
-    b : str, number, `datetime.datetime`, `datetime.timedelta`, `astropy.units.Quantity` (time)
-        Another time (usually the end time) specified as a
+    b : {parse_time_types}
+        Another time (the end time) specified as a
         parse_time-compatible time string, number, or a datetime object.
         May also be the size of the time range specified as a timedelta object,
-        or a `astropy.units.Quantity`.
+        or a `~astropy.units.Quantity`.
 
     Examples
     --------
     >>> from sunpy.time import TimeRange
-    >>> import astropy.units as u
     >>> time_range = TimeRange('2010/03/04 00:10', '2010/03/04 00:20')
     >>> time_range = TimeRange(('2010/03/04 00:10', '2010/03/04 00:20'))
+    >>> import astropy.units as u
     >>> time_range = TimeRange('2010/03/04 00:10', 400 * u.s)
-    >>> TimeRange('2010/03/04 00:10', 400 * u.day) # doctest:+ELLIPSIS
+    >>> TimeRange('2010/03/04 00:10', 400 * u.day)
        <sunpy.time.timerange.TimeRange object at ...>
         Start: 2010-03-04 00:10:00
         End:   2011-04-08 00:10:00
@@ -52,8 +55,7 @@ class TimeRange(object):
                34560000.0 seconds
     <BLANKLINE>
     """
-    def __init__(self, a, b=None):
-        """Creates a new TimeRange instance"""
+    def __init__(self, a, b=None, format=None):
         # If a is a TimeRange object, copy attributes to new instance.
         self._t1 = None
         self._t2 = None
@@ -64,21 +66,24 @@ class TimeRange(object):
 
         # Normalize different input types
         if b is None:
-            x = parse_time(a[0])
+            x = parse_time(a[0], format=format)
             if len(a) != 2:
                 raise ValueError('If b is None a must have two elements')
             else:
                 y = a[1]
         else:
-            x = parse_time(a)
+            x = parse_time(a, format=format)
             y = b
 
         if isinstance(y, u.Quantity):
-            y = timedelta(seconds=y.to('s').value)
+            y = TimeDelta(y)
+
+        if isinstance(y, timedelta):
+            y = TimeDelta(y, format='datetime')
 
         # Timedelta
-        if isinstance(y, timedelta):
-            if y.days >= 0:
+        if isinstance(y, TimeDelta):
+            if y.jd >= 0:
                 self._t1 = x
                 self._t2 = x + y
             else:
@@ -87,9 +92,9 @@ class TimeRange(object):
             return
 
         # Otherwise, assume that the second argument is parse_time-compatible
-        y = parse_time(y)
+        y = parse_time(y, format=format)
 
-        if isinstance(y, datetime):
+        if isinstance(y, Time):
             if x < y:
                 self._t1 = x
                 self._t2 = y
@@ -100,22 +105,24 @@ class TimeRange(object):
     @property
     def start(self):
         """
-        Get the start time
+        Get the start time.
 
         Returns
         -------
-        start : `datetime.datetime`
+        `astropy.time.Time`
+            The start time.
         """
         return self._t1
 
     @property
     def end(self):
         """
-        Get the end time
+        Get the end time.
 
         Returns
         -------
-        end : `datetime.datetime`
+        `astropy.time.Time`
+            The end time.
         """
         return self._t2
 
@@ -126,20 +133,22 @@ class TimeRange(object):
 
         Returns
         -------
-        dt : `datetime.timedelta`
+        `astropy.time.TimeDelta`
+            The difference between the start and the end time.
         """
         return self._t2 - self._t1
 
     @property
     def center(self):
         """
-        Gets the center of the TimeRange instance.
+        Gets the center of the time range.
 
         Returns
         -------
-        value : `datetime.datetime`
+        `astropy.time.Time`
+           The center time.
         """
-        return self.start + self.dt // 2
+        return self.start + self.dt / 2
 
     @property
     def hours(self):
@@ -148,9 +157,10 @@ class TimeRange(object):
 
         Returns
         -------
-        value : `astropy.units.Quantity`
+        `astropy.units.Quantity`
+           The amount of hours between the start and end time.
         """
-        return self._duration.to('hour')
+        return self.dt.to('hour')
 
     @property
     def days(self):
@@ -159,9 +169,10 @@ class TimeRange(object):
 
         Returns
         -------
-        value : `astropy.units.Quantity`
+        `astropy.units.Quantity`
+            The amount of days between the start and end time.
         """
-        return self._duration.to('d')
+        return self.dt.to('d')
 
     @property
     def seconds(self):
@@ -170,9 +181,10 @@ class TimeRange(object):
 
         Returns
         -------
-        value : `astropy.units.Quantity`
+        `astropy.units.Quantity`
+           The amount of seconds between the start and end time.
         """
-        return self._duration.to('s')
+        return self.dt.to('s')
 
     @property
     def minutes(self):
@@ -181,68 +193,63 @@ class TimeRange(object):
 
         Returns
         -------
-        value : `astropy.units.Quantity`
+        `astropy.units.Quantity`
+           The amount of minutes between the start and end time.
         """
-        return self._duration.to('min')
-
-    @property
-    def _duration(self):
-        """
-        The duration of the time range.
-
-        Returns
-        -------
-        value : `astropy.units.Quantity`
-        """
-        return self.dt.total_seconds() * u.s
+        return self.dt.to('min')
 
     def __eq__(self, other):
         """
-        Check two TimeRange objects have the same start and end datetime.
+        Check that two `sunpy.time.TimeRange` have the same start and end
+        datetime.
 
         Parameters
         ----------
         other : `~sunpy.time.timerange.TimeRange`
-            The second TimeRange object to compare to.
+            The second `sunpy.time.TimeRange` to compare to.
 
         Returns
         -------
-        result : `bool`
+        `bool`
+            `True` if equal, `False` otherwise.
         """
         if isinstance(other, TimeRange):
-            return (self.start == other.start) and (self.end == other.end)
+            return is_time_equal(
+                self.start, other.start) and is_time_equal(self.end, other.end)
 
         return NotImplemented
 
     def __ne__(self, other):
         """
-        Check two TimeRange objects have different start or end datetimes.
+        Check two `sunpy.time.TimeRange` have different start or end datetimes.
 
         Parameters
         ----------
         other : `~sunpy.time.timerange.TimeRange`
-            The second TimeRange object to compare to.
+            The second `sunpy.time.TimeRange` to compare to.
 
         Returns
         -------
-        result : `bool`
+        `bool`
+            `True` if non-equal, `False` otherwise.
         """
         if isinstance(other, TimeRange):
-            return (self.start != other.start) or (self.end != other.end)
+            return not (is_time_equal(
+                self.start, other.start) and is_time_equal(self.end, other.end))
 
         return NotImplemented
 
     def __repr__(self):
         """
-        Returns a human-readable representation of the TimeRange instance.
+        Returns a human-readable representation of `sunpy.time.TimeRange`.
         """
 
         t1 = self.start.strftime(TIME_FORMAT)
         t2 = self.end.strftime(TIME_FORMAT)
         center = self.center.strftime(TIME_FORMAT)
-        fully_qualified_name = '{0}.{1}'.format(self.__class__.__module__, self.__class__.__name__)
+        fully_qualified_name = f'{self.__class__.__module__}.{self.__class__.__name__}'
 
-        return ('   <{0} object at {1}>'.format(fully_qualified_name, hex(id(self))) +
+        return ('   <{} object at {}>'.format(fully_qualified_name, hex(id(self))) +
                 '\n    Start:'.ljust(12) + t1 +
                 '\n    End:'.ljust(12) + t2 +
                 '\n    Center:'.ljust(12) + center +
@@ -254,23 +261,18 @@ class TimeRange(object):
 
     def split(self, n=2):
         """
-        Splits the TimeRange into multiple equally sized parts.
+        Splits the time range into multiple equally sized parts.
 
         Parameters
         ----------
-        n : int
-            The number of times to split the time range (must >= 1)
+        n : `int`, optional
+            The number of times to split the time range (must >= 1).
+            Defaults to 2.
 
         Returns
         -------
-        time ranges: list
-            An list of equally sized TimeRange objects between
-            the start and end times.
-
-        Raises
-        ------
-        ValueError
-            If requested amount is less than 1
+        `list`
+            A list of equally sized `sunpy.time.TimeRange` between the start and end times.
         """
         if n <= 0:
             raise ValueError('n must be greater than or equal to 1')
@@ -278,7 +280,7 @@ class TimeRange(object):
         previous_time = self.start
         next_time = None
         for _ in range(n):
-            next_time = previous_time + self.dt // n
+            next_time = previous_time + self.dt / n
             next_range = TimeRange(previous_time, next_time)
             subsections.append(next_range)
             previous_time = next_time
@@ -286,21 +288,21 @@ class TimeRange(object):
 
     def window(self, cadence, window):
         """
-        Split the TimeRange up into a series of TimeRange windows,
-        'window' long, between the start and end with a cadence of 'cadence'.
+        Split the time range up into a series of `~sunpy.time.TimeRange` that
+        are ``window`` long, with a cadence of ``cadence``.
 
         Parameters
         ----------
-        cadence : `astropy.units.Quantity`, `datetime.timedelta`
-            Cadence in seconds or a timedelta instance
-        window : `astropy.units.quantity`, `datetime.timedelta`
-            The length of the Time's, assumed to be seconds if int.
+        cadence : `astropy.units.Quantity`, `astropy.time.TimeDelta`
+            Cadence.
+        window : `astropy.units.quantity`, `astropy.time.TimeDelta`
+            The length of window.
 
         Returns
         -------
-        time ranges : list
-            A list of TimeRange objects, that are window long and separated by
-            cadence.
+        `list`
+            A list of `~sunpy.time.TimeRange`, that are ``window`` long
+            and separated by ``cadence``.
 
         Examples
         --------
@@ -332,12 +334,17 @@ class TimeRange(object):
                     0.003333333333333333 hours or
                     0.2 minutes or
                     12.0 seconds]
-
         """
-        if not isinstance(window, timedelta):
-            window = timedelta(seconds=window.to('s').value)
-        if not isinstance(cadence, timedelta):
-            cadence = timedelta(seconds=cadence.to('s').value)
+        # TODO: After astropy 3.1 remove this check
+        if isinstance(window, timedelta):
+            window = TimeDelta(window, format="datetime")
+        if isinstance(cadence, timedelta):
+            cadence = TimeDelta(cadence, format="datetime")
+
+        if not isinstance(window, TimeDelta):
+            window = TimeDelta(window)
+        if not isinstance(cadence, TimeDelta):
+            cadence = TimeDelta(cadence)
 
         n = 1
         times = [TimeRange(self.start, self.start + window)]
@@ -348,7 +355,9 @@ class TimeRange(object):
         return times
 
     def next(self):
-        """Shift the time range forward by the amount of time elapsed"""
+        """
+        Shift the time range forward by the amount of time elapsed.
+        """
         dt = self.dt
         self._t1 = self._t1 + dt
         self._t2 = self._t2 + dt
@@ -356,7 +365,9 @@ class TimeRange(object):
         return self
 
     def previous(self):
-        """Shift the time range backward by the amount of time elapsed"""
+        """
+        Shift the time range backward by the amount of time elapsed.
+        """
         dt = self.dt
         self._t1 = self._t1 - dt
         self._t2 = self._t2 - dt
@@ -364,42 +375,47 @@ class TimeRange(object):
         return self
 
     def extend(self, dt_start, dt_end):
-        """Extend the time range forwards and backwards
+        """
+        Extend the time range forwards and backwards.
 
         Parameters
         ----------
-        dt_start : `datetime.timedelta`
-            The amount to shift the start time
-        dt_end : `datetime.timedelta`
-            The amount to shift the end time
+        dt_start : `astropy.time.TimeDelta`
+            The amount to shift the start time.
+        dt_end : `astropy.time.TimeDelta`
+            The amount to shift the end time.
         """
-        # Only a timedelta object is acceptable here
+        # TODO: Support datetime.timedelta
         self._t1 = self._t1 + dt_start
         self._t2 = self._t2 + dt_end
 
     def get_dates(self):
         """
-        Return all partial days contained within the timerange
+        Return all partial days contained within the time range.
         """
         dates = []
-        dates = [self.start.date() + timedelta(days=i) for i in range(int(self.days.value) + 1)]
+        dates = [
+            parse_time(self.start.strftime('%Y-%m-%d')) + TimeDelta(i*u.day)
+            for i in range(int(self.days.value) + 1)
+        ]
         return dates
 
+    @add_common_docstring(**_variables_for_parse_time_docstring())
     def __contains__(self, time):
         """
-        Checks whether the given time lies within this range.
-        Both limits are inclusive (i.e. __contains__(t1) and __contains__(t2)
-        always return true)
+        Checks whether the given time lies within this range. Both limits are
+        inclusive (i.e., ``__contains__(t1)`` and ``__contains__(t2)`` always
+        return `True).that.
 
         Parameters
         ----------
-        time : `datetime.datetime`, str
-            A parse_time-compatible time to be checked.
+        time : {parse_time_types}
+            {parse_time_desc}
 
         Returns
         -------
-        value : bool
-            True if time lies between start and end, False otherwise.
+        `bool`
+            `True` if time lies between start and end, `False` otherwise.
 
         Examples
         --------
