@@ -1,18 +1,21 @@
-# -*- coding: utf-8 -*-
-"""RHESSI TimeSeries subclass definitions."""
-from __future__ import absolute_import
-
-from collections import OrderedDict
+"""
+This module provies a RHESSI `~sunpy.timeseries.TimeSeries` source.
+"""
 import datetime
+from collections import OrderedDict
+
 import matplotlib.dates
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 from pandas import DataFrame
 
+import astropy.units as u
+
+import sunpy.io
+from sunpy.instr import rhessi
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
 from sunpy.util.metadata import MetaDict
-from sunpy.instr import rhessi
-import sunpy.io
-from astropy import units as u
+from sunpy.visualization import peek_show
 
 __all__ = ['RHESSISummaryTimeSeries']
 
@@ -21,15 +24,14 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
     """
     RHESSI X-ray Summary Lightcurve TimeSeries.
 
-    The RHESSI mission consists of a single spin-stabilized
-    spacecraft in a low-altitude orbit inclined 38 degrees to
-    the Earth's equator. The only instrument on board is a set of 9
-    Germanium spectrometers with the ability to obtain high
-    fidelity solar spectra from X rays (down to 3 keV) to gamma rays (1 MeV).
-    Each spectrometer is coupled to a set of grids with different pitches
-    which enable fourier-style imaging as the spacecraft spins.
+    The RHESSI mission consists of a single spin-stabilized spacecraft in a low-altitude orbit
+    inclined 38 degrees to the Earth's equator.
+    The only instrument on board is a set of 9 Germanium spectrometers with the ability to
+    obtain high fidelity solar spectra from X rays (down to 3 keV) to gamma rays (1 MeV).
+    Each spectrometer is coupled to a set of grids with different pitches which enable
+    fourier-style imaging as the spacecraft spins.
 
-    RHESSI provides summary lightcurves in the following passbands
+    RHESSI provides summary lightcurves in the following passbands:
 
     * 3 - 6 keV
     * 6 - 12 keV
@@ -41,26 +43,28 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
     * 800 - 7000 keV
     * 7000 - 20000 keV
 
-    RHESSI was launched on 5 February 2002.
+    RHESSI was launched on 5th February 2002.
 
     Examples
     --------
     >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
     >>> import sunpy.timeseries
     >>> rhessi = sunpy.timeseries.TimeSeries(sunpy.data.sample.RHESSI_TIMESERIES)  # doctest: +REMOTE_DATA
-    >>> rhessi.peek()   # doctest: +SKIP
+    >>> rhessi.peek()  # doctest: +SKIP
 
     References
     ----------
-    * RHESSI Homepage `<https://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
-    * Mission Paper `<https://doi.org/10.1023/A:1022428818870>`_
+    * `RHESSI Homepage. <https://hesperia.gsfc.nasa.gov/rhessi3/index.html>`_
+    * `Mission Paper. <https://doi.org/10.1023/A:1022428818870>`_
     """
 
     # Class attribute used to specify the source class of the TimeSeries.
     _source = 'rhessi'
 
-    def peek(self, title="RHESSI Observing Summary Count Rate", **kwargs):
-        """Plots RHESSI Count Rate light curve. An example is shown below.
+    @peek_show
+    def peek(self, title="RHESSI Observing Summary Count Rate"):
+        """
+        Plots RHESSI Count Rate light curve. An example is shown below:
 
         .. plot::
 
@@ -73,10 +77,6 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         ----------
         title : `str`
             The title of the plot.
-
-        **kwargs : `dict`
-            Any additional plot arguments that should be used
-            when plotting.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_ploting()
@@ -86,7 +86,7 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
 
         lc_linecolors = rhessi.hsi_linecolors()
 
-        for lc_color, (item, frame) in zip(lc_linecolors, self.data.iteritems()):
+        for lc_color, (item, frame) in zip(lc_linecolors, self.data.items()):
             axes.plot_date(self.data.index, frame.values, '-', label=item, lw=2, color=lc_color)
 
         axes.set_yscale("log")
@@ -99,25 +99,41 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
         axes.xaxis.grid(False, 'major')
         axes.legend()
 
-        # @todo: display better tick labels for date range (e.g. 06/01 - 06/05)
+        # TODO: display better tick labels for date range (e.g. 06/01 - 06/05)
         formatter = matplotlib.dates.DateFormatter('%H:%M')
         axes.xaxis.set_major_formatter(formatter)
 
         axes.fmt_xdata = matplotlib.dates.DateFormatter('%H:%M')
         figure.autofmt_xdate()
-        figure.show()
+
+        return figure
 
     @classmethod
     def _parse_file(cls, filepath):
-        """Parses rhessi FITS data files to create TimeSeries."""
-        #header, d, hdus = rhessi.parse_obssumm_file(filepath)
+        """
+        Parses rhessi FITS data files to create TimeSeries.
+
+        Parameters
+        ----------
+        filepath : `str`
+            The path to the file you want to parse.
+        """
         hdus = sunpy.io.read_file(filepath)
         return cls._parse_hdus(hdus)
 
     @classmethod
     def _parse_hdus(cls, hdulist):
-        """Parses a RHESSI FITS HDU list form a FITS file."""
-        header, d = rhessi.parse_obssumm_hdulist(hdulist)
+        """
+        Parses a RHESSI `astropy.io.fits.HDUList` from a FITS file.
+
+        Parameters
+        ----------
+        hdulist : `astropy.io.fits.HDUList`
+            A HDU list.
+        """
+        header, d = rhessi.parse_observing_summary_hdulist(hdulist)
+        # The time of dict `d` is astropy.time, but dataframe can only take datetime
+        d['time'] = d['time'].datetime
         header = MetaDict(OrderedDict(header))
         data = DataFrame(d['data'], columns=d['labels'], index=d['time'])
         # Add the units data
@@ -135,7 +151,10 @@ class RHESSISummaryTimeSeries(GenericTimeSeries):
 
     @classmethod
     def is_datasource_for(cls, **kwargs):
-        """Determines if the file corresponds to a RHESSI X-ray Summary lightcurve"""
+        """
+        Determines if the file corresponds to a RHESSI X-ray Summary
+        `~sunpy.timeseries.TimeSeries`.
+        """
         # Check if source is explicitly assigned
         if 'source' in kwargs.keys():
             if kwargs.get('source', ''):
