@@ -1,45 +1,37 @@
-# -*- coding: utf-8 -*-
-"""
-Test Generic TimeSeries
-
-Created on Thu Jun 23 12:29:55 2016
-
-@author: alex_
-"""
-
 import os
-import glob
-import pytest
-import datetime
-import warnings
 import copy
+import glob
+import datetime
+from collections import OrderedDict
 
 import numpy as np
-import astropy.units as u
-from pandas.util.testing import assert_frame_equal
-from pandas import DataFrame
 import pandas as pd
-from collections import OrderedDict
-from astropy.tests.helper import assert_quantity_allclose
+import pytest
+from pandas import DataFrame
+from pandas.util.testing import assert_frame_equal
+
+import astropy.units as u
 from astropy.table import Table
-from astropy.time import Time
+from astropy.tests.helper import assert_quantity_allclose
+from astropy.time import TimeDelta
 
 import sunpy
-from sunpy.time import TimeRange, parse_time
-import sunpy.timeseries
-from sunpy.util.metadata import MetaDict
-from sunpy.timeseries import TimeSeriesMetaData
-from sunpy.tests.helpers import figure_test
-
 import sunpy.data.test
+import sunpy.timeseries
+from sunpy.tests.helpers import figure_test
+from sunpy.time import TimeRange, parse_time
+from sunpy.timeseries import TimeSeriesMetaData
+from sunpy.util import SunpyUserWarning
+from sunpy.util.metadata import MetaDict
 
-#==============================================================================
+# =============================================================================
 # TimeSeries Tests
-#==============================================================================
+# =============================================================================
 
 filepath = sunpy.data.test.rootdir
 
 eve_filepath = os.path.join(filepath, 'EVE_L0CS_DIODES_1m_truncated.txt')
+esp_filepath = os.path.join(filepath, 'eve_l1_esp_2011046_00_truncated.fits')
 fermi_gbm_filepath = os.path.join(filepath, 'gbm.fits')
 norh_filepath = os.path.join(filepath, 'tca110810_truncated')
 goes_filepath = os.path.join(filepath, 'goes.fits')
@@ -58,49 +50,56 @@ a_list_of_many = glob.glob(os.path.join(filepath, "eve", "*"))
 
 @pytest.fixture
 def eve_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='EVE')
-    return sunpy.timeseries.TimeSeries(eve_filepath, source='EVE')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='EVE')
+    with pytest.warns(SunpyUserWarning, match='Unknown units'):
+        return sunpy.timeseries.TimeSeries(eve_filepath, source='EVE')
 
 
+@pytest.fixture
+def esp_test_ts():
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='ESP')
+    return sunpy.timeseries.TimeSeries(esp_filepath, source='ESP')
+
 @pytest.fixture
 def fermi_gbm_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='GBMSummary')
-    return sunpy.timeseries.TimeSeries(fermi_gbm_filepath, source='GBMSummary')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='GBMSummary')
+    with pytest.warns(UserWarning, match='Discarding nonzero nanoseconds'):
+        return sunpy.timeseries.TimeSeries(fermi_gbm_filepath, source='GBMSummary')
 
 
 @pytest.fixture
 def norh_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NoRH')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NoRH')
     return sunpy.timeseries.TimeSeries(norh_filepath, source='NoRH')
 
 
 @pytest.fixture
 def goes_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='XRS')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='XRS')
     return sunpy.timeseries.TimeSeries(goes_filepath, source='XRS')
 
 
 @pytest.fixture
 def lyra_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='LYRA')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='LYRA')
     return sunpy.timeseries.TimeSeries(lyra_filepath, source='LYRA')
 
 
 @pytest.fixture
 def rhessi_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='RHESSI')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='RHESSI')
     return sunpy.timeseries.TimeSeries(rhessi_filepath, source='RHESSI')
 
 
 @pytest.fixture
 def noaa_ind_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NOAAIndices')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NOAAIndices')
     return sunpy.timeseries.TimeSeries(noaa_ind_filepath, source='NOAAIndices')
 
 
 @pytest.fixture
 def noaa_pre_test_ts():
-    #ToDo: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NOAAPredictIndices')
+    # TODO: return sunpy.timeseries.TimeSeries(os.path.join(testpath, filename), source='NOAAPredictIndices')
     return sunpy.timeseries.TimeSeries(
         noaa_pre_filepath, source='NOAAPredictIndices')
 
@@ -109,11 +108,11 @@ def noaa_pre_test_ts():
 def generic_ts():
     # Generate the data and the corrisponding dates
     base = parse_time("2016/10/01T05:00:00")
-    dates = [base - datetime.timedelta(minutes=x) for x in range(0, 24 * 60)]
+    dates = base - TimeDelta(np.arange(24 * 60)*u.minute)
     intensity = np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24 * 60))))
 
     # Create the data DataFrame, header MetaDict and units OrderedDict
-    data = DataFrame(intensity, index=dates, columns=['intensity'])
+    data = DataFrame(intensity, index=dates.isot.astype('datetime64'), columns=['intensity'])
     units = OrderedDict([('intensity', u.W / u.m**2)])
     meta = MetaDict({'key': 'value'})
 
@@ -123,23 +122,22 @@ def generic_ts():
 
 @pytest.fixture
 def concatenate_multi_files_ts():
-    return sunpy.timeseries.TimeSeries(
-        a_list_of_many, source='EVE', concatenate=True)
+    with pytest.warns(SunpyUserWarning, match='Unknown units'):
+        return sunpy.timeseries.TimeSeries(
+            a_list_of_many, source='EVE', concatenate=True)
 
-#==============================================================================
+# =============================================================================
 # Test Creating TimeSeries From Various Dataformats
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
 def table_ts():
     # Generate the data and the corresponding dates
-    base = datetime.datetime.today()
-    times = Time(
-        [base - datetime.timedelta(minutes=x) for x in range(0, 24 * 60)])
+    base = parse_time(datetime.datetime.today())
+    times = base - TimeDelta(np.arange(24 * 60)*u.minute)
     intensity = u.Quantity(
-        np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24 * 60)))), u.W / u.m
-        **2)
+        np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24 * 60)))), u.W / u.m ** 2)
 
     # Create the units and meta objects
     units = OrderedDict([('intensity', u.W / u.m**2)])
@@ -154,15 +152,16 @@ def table_ts():
     # Create TS from dataframe and check
     return sunpy.timeseries.TimeSeries(table, meta, units)
 
-#==============================================================================
+# =============================================================================
 # Test Resulting TimeSeries Parameters
-#==============================================================================
+# =============================================================================
 
 
-def test_units_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
+def test_units_type(eve_test_ts, esp_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
                     lyra_test_ts, rhessi_test_ts, noaa_ind_test_ts,
                     noaa_pre_test_ts, generic_ts, table_ts):
     assert isinstance(eve_test_ts.units, OrderedDict)
+    assert isinstance(esp_test_ts.units, OrderedDict)
     assert isinstance(fermi_gbm_test_ts.units, OrderedDict)
     assert isinstance(norh_test_ts.units, OrderedDict)
     assert isinstance(goes_test_ts.units, OrderedDict)
@@ -174,10 +173,11 @@ def test_units_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
     assert isinstance(table_ts.units, OrderedDict)
 
 
-def test_meta_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
+def test_meta_type(eve_test_ts, esp_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
                    lyra_test_ts, rhessi_test_ts, noaa_ind_test_ts,
                    noaa_pre_test_ts, generic_ts, table_ts):
     assert isinstance(eve_test_ts.meta, TimeSeriesMetaData)
+    assert isinstance(esp_test_ts.meta, TimeSeriesMetaData)
     assert isinstance(fermi_gbm_test_ts.meta, TimeSeriesMetaData)
     assert isinstance(norh_test_ts.meta, TimeSeriesMetaData)
     assert isinstance(goes_test_ts.meta, TimeSeriesMetaData)
@@ -189,10 +189,11 @@ def test_meta_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
     assert isinstance(table_ts.meta, TimeSeriesMetaData)
 
 
-def test_data_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
+def test_data_type(eve_test_ts, esp_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
                    lyra_test_ts, rhessi_test_ts, noaa_ind_test_ts,
                    noaa_pre_test_ts, generic_ts, table_ts):
     assert isinstance(eve_test_ts.data, DataFrame)
+    assert isinstance(esp_test_ts.data, DataFrame)
     assert isinstance(fermi_gbm_test_ts.data, DataFrame)
     assert isinstance(norh_test_ts.data, DataFrame)
     assert isinstance(goes_test_ts.data, DataFrame)
@@ -203,11 +204,11 @@ def test_data_type(eve_test_ts, fermi_gbm_test_ts, norh_test_ts, goes_test_ts,
     assert isinstance(generic_ts.data, DataFrame)
     assert isinstance(table_ts.data, DataFrame)
 
-    # ToDo: check length? (should match the number of columns)
+    # TODO: check length? (should match the number of columns)
 
-#==============================================================================
+# =============================================================================
 # Test Basic Single-Timeseries Truncation Operations
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
@@ -266,18 +267,18 @@ def test_truncation_dates(eve_test_ts, truncation_dates_test_ts):
     assert truncation_dates_test_ts.time_range == truncation_dates_test_ts.meta.time_range == eve_test_ts.time_range.split(
         3)[1]
 
-#==============================================================================
+# =============================================================================
 # Test Basic Single-Timeseries Truncation Operations
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
 def truncated_none_ts(concatenate_multi_files_ts):
     # This timerange covers the whole range of metadata, so no change is expected
     a = concatenate_multi_files_ts.meta.metadata[0][
-        0].start - datetime.timedelta(days=1)
+        0].start - TimeDelta(1*u.day)
     b = concatenate_multi_files_ts.meta.metadata[-1][
-        0].end + datetime.timedelta(days=1)
+        0].end + TimeDelta(1*u.day)
     tr = TimeRange(a, b)
     truncated = copy.deepcopy(concatenate_multi_files_ts)
     truncated = truncated.truncate(tr)
@@ -293,7 +294,7 @@ def truncated_start_ts(concatenate_multi_files_ts):
     # This time range starts after the original, so expect truncation
     a = concatenate_multi_files_ts.meta.metadata[1][0].center
     b = concatenate_multi_files_ts.meta.metadata[-1][
-        0].end + datetime.timedelta(days=1)
+        0].end + TimeDelta(1*u.day)
     tr = TimeRange(a, b)
     truncated = copy.deepcopy(concatenate_multi_files_ts)
     truncated = truncated.truncate(tr)
@@ -319,7 +320,7 @@ def test_truncated_start_ts(concatenate_multi_files_ts, truncated_start_ts):
 def truncated_end_ts(concatenate_multi_files_ts):
     # This time range ends before the original, so expect truncation
     a = concatenate_multi_files_ts.meta.metadata[0][
-        0].start - datetime.timedelta(days=1)
+        0].start - TimeDelta(1*u.day)
     b = concatenate_multi_files_ts.meta.metadata[-2][0].center
     tr = TimeRange(a, b)
     truncated = copy.deepcopy(concatenate_multi_files_ts)
@@ -382,9 +383,9 @@ def test_truncated_both_ts(concatenate_multi_files_ts, truncated_both_ts):
 def truncated_new_tr_all_before_ts(concatenate_multi_files_ts):
     # Time range begins and ends before the data
     a = concatenate_multi_files_ts.meta.metadata[0][
-        0].start - datetime.timedelta(days=2)
+        0].start - TimeDelta(2*u.day)
     b = concatenate_multi_files_ts.meta.metadata[0][
-        0].start - datetime.timedelta(days=1)
+        0].start - TimeDelta(1*u.day)
     tr = TimeRange(a, b)
     truncated = copy.deepcopy(concatenate_multi_files_ts)
     truncated = truncated.truncate(tr)
@@ -395,9 +396,9 @@ def truncated_new_tr_all_before_ts(concatenate_multi_files_ts):
 def truncated_new_tr_all_after_ts(concatenate_multi_files_ts):
     # Time range begins and ends after the data
     a = concatenate_multi_files_ts.meta.metadata[-1][
-        0].end + datetime.timedelta(days=1)
+        0].end + TimeDelta(1*u.day)
     b = concatenate_multi_files_ts.meta.metadata[-1][
-        0].end + datetime.timedelta(days=2)
+        0].end + TimeDelta(2*u.day)
     tr = TimeRange(a, b)
     truncated = copy.deepcopy(concatenate_multi_files_ts)
     truncated = truncated.truncate(tr)
@@ -408,9 +409,9 @@ def test_truncated_outside_tr_ts(truncated_new_tr_all_before_ts,
                                  truncated_new_tr_all_after_ts):
     assert truncated_new_tr_all_before_ts.meta.metadata == truncated_new_tr_all_after_ts.meta.metadata == []
 
-#==============================================================================
+# =============================================================================
 # Test Extraction Operations
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
@@ -434,9 +435,9 @@ def test_extraction(eve_test_ts, extraction_test_ts):
     extracted_df = extracted_df.sort_index()
     assert_frame_equal(extraction_test_ts.data, extracted_df)
 
-#==============================================================================
+# =============================================================================
 # Test Concatenation Operations
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
@@ -463,14 +464,15 @@ def test_concatenation_of_slices(eve_test_ts, concatenated_slices_test_ts):
 @pytest.fixture
 def concatenation_different_data_test_ts(eve_test_ts, fermi_gbm_test_ts):
     # Take two different data sources and concatenate
-    return eve_test_ts.concatenate(fermi_gbm_test_ts)
+    with pytest.warns(UserWarning, match='Discarding nonzero nanoseconds'):
+        return eve_test_ts.concatenate(fermi_gbm_test_ts)
 
 
 def test_concatenation_of_different_data(eve_test_ts, fermi_gbm_test_ts,
                                          concatenation_different_data_test_ts):
-    # ToDo: test the metadata is as expected using the below. (note ATM this fails if the order is changed)
-    #assert concatenation_different_data_test_ts.meta.metadata[0] == fermi_gbm_test_ts.meta.metadata[0]
-    #assert concatenation_different_data_test_ts.meta.metadata[1] == eve_test_ts.meta.metadata[0]
+    # TODO: test the metadata is as expected using the below. (note ATM this fails if the order is changed)
+    # assert concatenation_different_data_test_ts.meta.metadata[0] == fermi_gbm_test_ts.meta.metadata[0]
+    # assert concatenation_different_data_test_ts.meta.metadata[1] == eve_test_ts.meta.metadata[0]
     value = True
     for key in list(concatenation_different_data_test_ts.meta.metadata[0][2]
                     .keys()):
@@ -491,7 +493,7 @@ def test_concatenation_of_different_data(eve_test_ts, fermi_gbm_test_ts,
         comined_units)
 
     # Test data is the concatenation
-    comined_df = pd.concat([eve_test_ts.data, fermi_gbm_test_ts.data])
+    comined_df = pd.concat([eve_test_ts.data, fermi_gbm_test_ts.data], sort=False)
     comined_df = comined_df.sort_index()
     assert_frame_equal(concatenation_different_data_test_ts.data, comined_df)
 
@@ -505,8 +507,8 @@ def test_concatenation_different_data_error(eve_test_ts, fermi_gbm_test_ts):
 
 def test_generic_construction_concatenation():
     # Generate the data and the corrisponding dates
-    base = datetime.datetime.today()
-    times = [base - datetime.timedelta(minutes=x) for x in range(0, 24 * 60)]
+    base = parse_time(datetime.datetime.today())
+    times = base - TimeDelta(np.arange(24 * 60)*u.minute)
     intensity1 = np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24 * 60))))
     intensity2 = np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24 * 60))))
 
@@ -514,7 +516,7 @@ def test_generic_construction_concatenation():
     data = DataFrame(intensity1, index=times, columns=['intensity'])
     data2 = DataFrame(intensity2, index=times, columns=['intensity2'])
     units = OrderedDict([('intensity', u.W / u.m**2)])
-    units2 = OrderedDict([('intensity', u.W / u.m**2)])
+    units2 = OrderedDict([('intensity2', u.W / u.m**2)])
     meta = MetaDict({'key': 'value'})
     meta2 = MetaDict({'key2': 'value2'})
 
@@ -528,9 +530,9 @@ def test_generic_construction_concatenation():
     assert ts_concat.columns == ['intensity', 'intensity2']
     assert len(ts_concat.meta.metadata) == 2
 
-#==============================================================================
+# =============================================================================
 # Test Data Manipulation
-#==============================================================================
+# =============================================================================
 
 
 @pytest.fixture
@@ -561,7 +563,7 @@ def test_add_column_from_quantity(eve_test_ts, add_column_from_quantity_ts,
         column_quantity)
     # Test the full list of columns are pressent
     assert set(add_column_from_quantity_ts.data.columns) == set(
-        eve_test_ts.data.columns) | set(['quantity_added'])
+        eve_test_ts.data.columns) | {'quantity_added'}
 
 
 @pytest.fixture
@@ -579,16 +581,16 @@ def test_add_column_from_array(eve_test_ts, add_column_from_array_ts,
 
     # Test the full list of columns are pressent
     assert set(add_column_from_array_ts.data.columns) == set(
-        eve_test_ts.data.columns) | set(['array_added'])
+        eve_test_ts.data.columns) | {'array_added'}
 
 
 def test_add_column_from_array_no_units(eve_test_ts, column_quantity):
     ts = eve_test_ts.add_column('array_added', column_quantity.value)
     assert (ts.quantity('array_added') == column_quantity.value).all()
 
-#==============================================================================
+# =============================================================================
 # Test Exporting to different formats
-#==============================================================================
+# =============================================================================
 
 
 def test_ts_to_table(generic_ts):
@@ -611,9 +613,9 @@ def test_ts_to_array(generic_ts):
     assert isinstance(arr, np.ndarray)
     assert len(arr) == len(generic_ts.data)
 
-#==============================================================================
+# =============================================================================
 # Test Basic Working Peek
-#==============================================================================
+# =============================================================================
 
 
 @figure_test
@@ -621,6 +623,11 @@ def test_eve_peek(eve_test_ts):
     eve_test_ts.peek()
 
 
+@figure_test
+def test_esp_peek(esp_test_ts):
+    esp_test_ts.peek()
+
+
 @figure_test
 def test_fermi_gbm_peek(fermi_gbm_test_ts):
     fermi_gbm_test_ts.peek()
@@ -631,6 +638,7 @@ def test_norh_peek(norh_test_ts):
     norh_test_ts.peek()
 
 
+# TODO: Fix this
 """
 @figure_test
 def test_goes_peek(goes_test_ts):
@@ -662,77 +670,88 @@ def test_noaa_pre_peek(noaa_pre_test_ts):
 def test_generic_ts_peek(generic_ts):
     generic_ts.peek()
 
-#==============================================================================
+# =============================================================================
 # Test Peek Of Invalid Data for all sources
-#==============================================================================
+# =============================================================================
 
 
 def test_eve_invalid_peek(eve_test_ts):
-    a = eve_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = eve_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = eve_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = eve_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = eve_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
+def test_esp_invalid_peek(esp_test_ts):
+    a = esp_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = esp_test_ts.time_range.start - TimeDelta(1*u.day)
+    empty_ts = esp_test_ts.truncate(TimeRange(a, b))
+    with pytest.raises(ValueError):
+        empty_ts.peek()
+
 
 def test_fermi_gbm_invalid_peek(fermi_gbm_test_ts):
-    a = fermi_gbm_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = fermi_gbm_test_ts.time_range.start - datetime.timedelta(days=1)
+    with pytest.warns(UserWarning, match='Discarding nonzero nanoseconds'):
+        a = fermi_gbm_test_ts.time_range.start - TimeDelta(2*u.day)
+
+    with pytest.warns(UserWarning, match='Discarding nonzero nanoseconds'):
+        b = fermi_gbm_test_ts.time_range.start - TimeDelta(1*u.day)
+
     empty_ts = fermi_gbm_test_ts.truncate(TimeRange(a, b))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError), pytest.warns(UserWarning, match='Discarding nonzero nanoseconds'):
         empty_ts.peek()
 
 
 def test_norh_invalid_peek(norh_test_ts):
-    a = norh_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = norh_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = norh_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = norh_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = norh_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
 
 def test_lyra_invalid_peek(lyra_test_ts):
-    a = lyra_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = lyra_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = lyra_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = lyra_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = lyra_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
 
 def test_rhessi_invalid_peek(rhessi_test_ts):
-    a = rhessi_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = rhessi_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = rhessi_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = rhessi_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = rhessi_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
 
 def test_noaa_ind_invalid_peek(noaa_ind_test_ts):
-    a = noaa_ind_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = noaa_ind_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = noaa_ind_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = noaa_ind_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = noaa_ind_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
 
 def test_noaa_pre_invalid_peek(noaa_pre_test_ts):
-    a = noaa_pre_test_ts.time_range.start - datetime.timedelta(days=2)
-    b = noaa_pre_test_ts.time_range.start - datetime.timedelta(days=1)
+    a = noaa_pre_test_ts.time_range.start - TimeDelta(2*u.day)
+    b = noaa_pre_test_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = noaa_pre_test_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
 
 def test_generic_ts_invalid_peek(generic_ts):
-    a = generic_ts.time_range.start - datetime.timedelta(days=2)
-    b = generic_ts.time_range.start - datetime.timedelta(days=1)
+    a = generic_ts.time_range.start - TimeDelta(2*u.day)
+    b = generic_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = generic_ts.truncate(TimeRange(a, b))
     with pytest.raises(ValueError):
         empty_ts.peek()
 
-#==============================================================================
+# =============================================================================
 # Test Other Functions
-#==============================================================================
+# =============================================================================
 
 
 def test_equality(generic_ts, table_ts):
@@ -755,11 +774,10 @@ def test_ts_index(generic_ts):
 def test_ts_sort_index(generic_ts):
     assert generic_ts.sort_index().data.equals(generic_ts.data.sort_index())
 
-#_validate_units
 
-#_validate_meta
-
-# ToDo:
-###Extracting column as quantity or array#ts_eve = ts_eve.add_column(colname, qua_new, overwrite=True)
-###Updating a column using quantity or array#ts_eve = ts_eve.add_column(colname, qua_new, overwrite=True)
-###Updating the units# ts_eve = ts_eve.add_column(colname, qua_new, unit=unit, overwrite=True)
+# TODO:
+# _validate_units
+# _validate_meta
+# Extracting column as quantity or array#ts_eve = ts_eve.add_column(colname, qua_new, overwrite=True)
+# Updating a column using quantity or array#ts_eve = ts_eve.add_column(colname, qua_new, overwrite=True)
+# Updating the units# ts_eve = ts_eve.add_column(colname, qua_new, unit=unit, overwrite=True)
