@@ -1,59 +1,52 @@
-from __future__ import absolute_import, division, print_function
-
-import warnings
+"""
+This module provies the `~sunpy.timeseries.TimeSeriesFactory` class.
+"""
 import os
-import glob
-from collections import OrderedDict
 import copy
+import glob
+import warnings
+from collections import OrderedDict
+from urllib.request import urlopen
 
 import numpy as np
 import pandas as pd
-import astropy.io.fits
-from astropy.table import Table
+
 import astropy
-from astropy.time import Time
+import astropy.io.fits
 import astropy.units as u
+from astropy.table import Table
+from astropy.time import Time
 
 import sunpy
-from sunpy.timeseries.timeseriesbase import GenericTimeSeries, TIMESERIES_CLASSES
-from sunpy.util.metadata import MetaDict
-
-from sunpy.io.file_tools import read_file, UnrecognizedFileTypeError
+from sunpy.io.file_tools import UnrecognizedFileTypeError, read_file
 from sunpy.io.fits import HDPair
 from sunpy.io.header import FileHeader
-
-from sunpy.util.net import download_file
+from sunpy.timeseries.timeseriesbase import GenericTimeSeries
 from sunpy.util import expand_list
 from sunpy.util.config import get_and_create_download_dir
+from sunpy.util.datatype_factory_base import (BasicRegistrationFactory, MultipleMatchError,
+                                              NoMatchError, ValidationFunctionError)
+from sunpy.util.metadata import MetaDict
+from sunpy.util.net import download_file
 
-from sunpy.util.datatype_factory_base import BasicRegistrationFactory
-from sunpy.util.datatype_factory_base import NoMatchError
-from sunpy.util.datatype_factory_base import MultipleMatchError
-from sunpy.util.datatype_factory_base import ValidationFunctionError
-from sunpy.extern import six
-
-from sunpy.extern.six.moves.urllib.request import urlopen
-
-__authors__ = ["Alex Hamilton, Russell Hewett, Stuart Mumford"]
-
-__all__ = ['TimeSeries', 'TimeSeriesFactory']
+__all__ = ['TimeSeries', 'TimeSeriesFactory', 'NoTimeSeriesFound',
+           'InvalidTimeSeriesInput', 'InvalidTimeSeriesType']
 
 
 class TimeSeriesFactory(BasicRegistrationFactory):
     """
     TimeSeries(*args, **kwargs)
 
-    TimeSeries factory class.  Used to create a variety of TimeSeries objects.
-    Valid time series types are specified by registering them with the factory.
+    TimeSeries factory class, used to create a variety of `~sunpy.timeseries.TimeSeries` objects.
+    Valid timeseries types are specified by registering them with the factory.
 
     Parameters
     ----------
-
     source : `str`, optional
         A string to select the observational source of the data, currently
         necessary to define how files should be read for all instruments.
-
-    concatenate : `bool`, optional, default:False
+    concatenate : `bool`, optional
+        Defaults to `False`.
         If set, combine any resulting list of TimeSeries objects into a single
         TimeSeries, using successive concatenate methods.
 
@@ -63,27 +56,25 @@ class TimeSeriesFactory(BasicRegistrationFactory):
     >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
     >>> my_timeseries = sunpy.timeseries.TimeSeries(sunpy.data.sample.GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
 
-    The SunPy TimeSeries factory accepts a wide variety of inputs for creating time series
+    The SunPy TimeSeries factory accepts a wide variety of inputs for creating timeseries
 
     * Preloaded tuples of (data, header) pairs or (data, header, units)
 
     >>> my_timeseries = sunpy.timeseries.TimeSeries((data, header))   # doctest: +SKIP
 
-    headers and units are some base of `dict` or `~collections.OrderedDict` or
-    `~sunpy.util.metadata.MetaDict`.
+    Headers and units must be either a `dict`, `~collections.OrderedDict` or `~sunpy.util.metadata.MetaDict`.
 
     * data, header pairs, or data, header units triples, not in tuples
 
     >>> my_timeseries = sunpy.timeseries.TimeSeries(data, header)  # doctest: +SKIP
     >>> my_timeseries = sunpy.timeseries.TimeSeries(data, header, units)  # doctest: +SKIP
 
-    * File names for files understood by sunpy.io and those not
+    * File names for files understood by `sunpy.io` and those not
 
     >>> my_timeseries = sunpy.timeseries.TimeSeries('filename.fits')   # doctest: +SKIP
     >>> my_timeseries = sunpy.timeseries.TimeSeries('filename.fits', source='lyra')  # doctest: +SKIP
 
-    * Multiple files can be combined into one TimeSeries, as long as they are
-    the same source   # doctest: +SKIP
+    * Multiple files can be combined into one TimeSeries, as long as they are the same source
 
     >>> my_timeseries = sunpy.timeseries.TimeSeries(['goesfile1.fits', 'goesfile2.fits'],
     ...                                             concatenate=True)  # doctest: +SKIP
@@ -111,26 +102,23 @@ class TimeSeriesFactory(BasicRegistrationFactory):
     ...                                             'file1.fits', url, 'eit_*.fits')  # doctest: +SKIP
     """
 
-    def _read_file(self, fname, **kwargs):
+    @staticmethod
+    def _read_file(fname, **kwargs):
         """
-        Test reading a file with sunpy.io for automatic source detection.
+        Reading a file with `sunpy.io` for automatic source detection.
 
         Parameters
         ----------
-
-        fname : filename
-
-        kwargs
+        fname : `str`
+            The file path to parse.
 
         Returns
         -------
-
-        parsed :  bool
-            True if file has been reading
-
-        pairs : list or string
-            List of (data, header) pairs if ``parsed`` is ``True`` or ``fname``
-            if ``False``
+        parsed : `bool`
+            `True` if file has been read.
+        pairs : `list` or `str`
+            List of ``(data, header)`` pairs if ``parsed`` is `True`,  ``fname`` if ``parsed`` is `False`.
+            `False` if the file is not supported or incorrect.
         """
         if 'source' not in kwargs.keys() or not kwargs['source']:
             try:
@@ -149,9 +137,11 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         else:
             return False, fname
 
-    def _validate_meta(self, meta):
+    @staticmethod
+    def _validate_meta(meta):
         """
         Validate a meta argument for use as metadata.
+
         Currently only validates by class.
         """
         if isinstance(meta, astropy.io.fits.header.Header):
@@ -163,13 +153,16 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         else:
             return False
 
-    def _validate_units(self, units, **kwargs):
-        """
-        Validates the astropy unit-information associated with a TimeSeries.
-        Should be a dictionary of some form (but not MetaDict) with only
-        astropy units for values.
+    @staticmethod
+    def _validate_units(units):
         """
+        Validates the astropy unit-information associated with a
+        `~sunpy.timeseries.TimeSeries`.
 
+        Should be a dictionary of some form (but not
+        `sunpy.util.metadict.MetaDict`) with only `astropy.units` for
+        values.
+        """
         warnings.simplefilter('always', Warning)
         result = True
 
@@ -185,22 +178,16 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         # Passed all the tests
         return result
 
-    def _from_table(self, t, **kwargs):
+    @staticmethod
+    def _from_table(t):
         """
         Extract the data, metadata and units from an astropy table for use in
-        constructing a TimeSeries.
+        constructing a `~sunpy.timeseries.TimeSeries`.
 
         Parameters
         ----------
-        t: `~astropy.table.table.Table`
-            The input table. The datetime column must be the first column or the
-            (single) primary key index.
-
-        Returns
-        -------
-        data : `~pandas.core.frame.DataFrame`
-        meta : `~sunpy.util.metadata.MetaDict`
-        units : `dict`
+        t: `~astropy.table.Table`
+            The input table. The datetime column must be the first column or the (single) primary key index.
         """
         table = copy.deepcopy(t)
         # Default the time index to the first column
@@ -235,8 +222,9 @@ class TimeSeriesFactory(BasicRegistrationFactory):
 
     def _parse_args(self, *args, **kwargs):
         """
-        Parses an args list for data-header pairs.  args can contain any
-        mixture of the following entries:
+        Parses an `args` list for data-header pairs. `args` can contain any mixture of the following
+        entries:
+
         * tuples of (data, header, unit) (1)
         * data, header not in a tuple (1)
         * filename, which will be read
@@ -245,28 +233,22 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         * url, which will be downloaded and read
         * lists containing any of the above.
 
-        (1) Note that header/unit are optional and in either order, but data
-        but be the first entry in each group.
+        (1) header/unit are optional and in either order, but data should be the first entry in each group.
 
-        Example
-        -------
+        Examples
+        --------
         self._parse_args(data, header,
                          (data, header),
                          ['file1', 'file2', 'file3'],
                          'file4',
                          'directory1',
                          '*.fits')
-
         """
-
         data_header_unit_tuples = list()
         data_header_pairs = list()
         already_timeseries = list()
         filepaths = list()
 
-        # Take source kwarg if defined
-        source = kwargs.get('source', None)
-
         # Account for nested lists of items. Simply outputs a single list of
         # items, nested lists are expanded to element level.
         args = expand_list(args)
@@ -312,20 +294,15 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                 data_header_unit_tuples.append((data, meta, units))
 
             # Filepath
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   os.path.isfile(os.path.expanduser(arg))):
 
                 path = os.path.expanduser(arg)
-
-                read, result = self._read_file(path, **kwargs)
-
-                if read:
-                    data_header_pairs.append(result)
-                else:
-                    filepaths.append(result)
+                result = self._read_file(path, **kwargs)
+                data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths, result)
 
             # Directory
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   os.path.isdir(os.path.expanduser(arg))):
 
                 path = os.path.expanduser(arg)
@@ -333,42 +310,33 @@ class TimeSeriesFactory(BasicRegistrationFactory):
                 for afile in files:
                     # returns a boolean telling us if it were read and either a
                     # tuple or the original filepath for reading by a source
-                    read, result = self._read_file(afile, **kwargs)
-                    if read:
-                        data_header_pairs.append(result)
-                    else:
-                        filepaths.append(result)
+                    result = self._read_file(afile, **kwargs)
+                    data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths,
+                                                                 result)
 
             # Glob
-            elif (isinstance(arg, six.string_types) and '*' in arg):
+            elif isinstance(arg, str) and '*' in arg:
 
                 files = glob.glob(os.path.expanduser(arg))
-
                 for afile in files:
-                    # data_header_unit_tuples += self._read_file(afile, **kwargs)
                     # returns a boolean telling us if it were read and either a
                     # tuple or the original filepath for reading by a source
-                    read, result = self._read_file(afile, **kwargs)
-                    if read:
-                        data_header_pairs.append(result)
-                    else:
-                        filepaths.append(result)
+                    result = self._read_file(afile, **kwargs)
+                    data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths,
+                                                                 result)
 
             # Already a TimeSeries
             elif isinstance(arg, GenericTimeSeries):
                 already_timeseries.append(arg)
 
             # A URL
-            elif (isinstance(arg, six.string_types) and
+            elif (isinstance(arg, str) and
                   _is_url(arg)):
                 url = arg
                 path = download_file(url, get_and_create_download_dir())
-                pairs = self._read_file(path, **kwargs)
-                # data_header_pairs += pairs
-                filepaths.append(pairs[1])
-
+                result = self._read_file(path, **kwargs)
+                data_header_pairs, filepaths = _apply_result(data_header_pairs, filepaths, result)
             else:
-                # raise ValueError("File not found or invalid input")
                 raise NoMatchError("File not found or invalid input")
             i += 1
 
@@ -377,30 +345,26 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         # same order as the input, currently they are not.
         return data_header_unit_tuples, data_header_pairs, already_timeseries, filepaths
 
-    def __call__(self, *args, **kwargs):
-        """ Method for running the factory. Takes arbitrary arguments and
-        keyword arguments and passes them to a sequence of pre-registered types
-        to determine which is the correct TimeSeries source type to build.
+    def __call__(self, *args, silence_errors=False, **kwargs):
+        """
+        Method for running the factory. Takes arbitrary arguments and keyword
+        arguments and passes them to a sequence of pre-registered types to
+        determine which is the correct `~sunpy.timeseries.TimeSeries` source
+        type to build.
 
-        Arguments args and kwargs are passed through to the validation
-        function and to the constructor for the final type.  For TimeSeries
-        types, validation function must take a data-header pair as an argument.
+        Arguments args and kwargs are passed through to the validation function and to the constructor for the final type.
+        For `~sunpy.timeseries.TimeSeries` types, validation function must take a data-header pair as an argument.
 
         Parameters
         ----------
-
         silence_errors : `bool`, optional
             If set, ignore data-header pairs which cause an exception.
+            Defaults to `False`.
 
         Notes
         -----
-        Extra keyword arguments are passed through to `sunpy.io.read_file` such
-        as `memmap` for FITS files.
+        Extra keyword arguments are passed through to `sunpy.io.read_file` such as `memmap` for FITS files.
         """
-
-        # Hack to get around Python 2.x not backporting PEP 3102.
-        silence_errors = kwargs.pop('silence_errors', False)
-
         (data_header_unit_tuples, data_header_pairs,
          already_timeseries, filepaths) = self._parse_args(*args, **kwargs)
 
@@ -410,14 +374,13 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         for filepath in filepaths:
             try:
                 new_ts = self._check_registered_widgets(filepath=filepath, **kwargs)
+                new_timeseries.append(new_ts)
             except (NoMatchError, MultipleMatchError, ValidationFunctionError):
                 if not silence_errors:
                     raise
-            except:
+            except Exception:
                 raise
 
-            new_timeseries.append(new_ts)
-
         # data_header_pairs is a list of HDUs as read by sunpy.io
         # For each set of HDus find the matching class and read the
         # data_header_unit_tuples by calling the _parse_hdus method
@@ -464,14 +427,13 @@ class TimeSeriesFactory(BasicRegistrationFactory):
             try:
                 new_ts = self._check_registered_widgets(data=data, meta=meta,
                                                         units=units, **kwargs)
+                new_timeseries.append(new_ts)
             except (NoMatchError, MultipleMatchError, ValidationFunctionError):
                 if not silence_errors:
                     raise
-            except:
+            except Exception:
                 raise
 
-            new_timeseries.append(new_ts)
-
         new_timeseries += already_timeseries
 
         # Concatenate the timeseries into one if specified.
@@ -509,7 +471,7 @@ class TimeSeriesFactory(BasicRegistrationFactory):
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types identified ({0})."
+            raise MultipleMatchError("Too many candidate types identified ({})."
                                      "Specify enough keywords to guarantee unique type "
                                      "identification.".format(n_matches))
 
@@ -518,11 +480,12 @@ class TimeSeriesFactory(BasicRegistrationFactory):
 
     def _check_registered_widgets(self, **kwargs):
         """
-        Checks the (instrument) source/s that are compatible with this given
-        file/data. Only if exactly one source is compatible will a TimeSeries
-        be returned.
-        """
+        Checks the (instrument) source(s) that are compatible with this given
+        file/data.
 
+        Only if exactly one source is compatible will a
+        `~sunpy.timeseries.TimeSeries` be returned.
+        """
         WidgetType = self._get_matching_widget(**kwargs)
 
         # Dealing with the fact that timeseries filetypes are less consistent
@@ -539,32 +502,46 @@ class TimeSeriesFactory(BasicRegistrationFactory):
         return WidgetType(data, meta, units, **kwargs)
 
 
+def _apply_result(data_header_pairs, filepaths, result):
+    read, result = result
+    if read:
+        data_header_pairs.append(result)
+    else:
+        filepaths.append(result)
+
+    return data_header_pairs, filepaths
+
+
 def _is_url(arg):
     try:
         urlopen(arg)
-    except:
+    except Exception:
         return False
     return True
 
 
 class InvalidTimeSeriesInput(ValueError):
-    """Exception to raise when input variable is not a TimeSeries instance and
-    does not point to a valid TimeSeries input file."""
-    pass
+    """
+    Exception to raise when input variable is not a
+    `~sunpy.timeseries.TimeSeries` instance and does not point to a valid
+    TimeSeries input file.
+    """
 
 
 class InvalidTimeSeriesType(ValueError):
-    """Exception to raise when an invalid type of time series is requested with
-    TimeSeries."""
-    pass
+    """
+    Exception to raise when an invalid type of timeseries is requested with
+    `~sunpy.timeseries.TimeSeries`.
+    """
 
 
 class NoTimeSeriesFound(ValueError):
-    """Exception to raise when input does not point to any valid time series or
-    files."""
-    pass
+    """
+    Exception to raise when input does not point to any valid
+    `~sunpy.timeseries.TimeSeries` or files.
+    """
 
 
-TimeSeries = TimeSeriesFactory(default_widget_type=GenericTimeSeries,
+TimeSeries = TimeSeriesFactory(registry=GenericTimeSeries._registry,
+                               default_widget_type=GenericTimeSeries,
                                additional_validation_functions=['is_datasource_for'])
-TimeSeries.registry = TIMESERIES_CLASSES
