@@ -1,11 +1,7 @@
-from __future__ import absolute_import
-# -*- coding: utf-8 -*-
-
 import sunpy
 
 
 def test_sysinfo():
-
     output = sunpy.util.get_sys_dict()
-
     assert isinstance(output, dict)
+    sunpy.system_info()
